# -*- coding: utf-8 -*-


from django.db import models, migrations
import datetime
import autoslug.fields
from decimal import Decimal
from django.db.migrations.operations.special import RunPython, RunSQL
import django.utils.timezone
from django.contrib.postgres.search import SearchVectorField
from django.contrib.postgres.fields import ArrayField
import django.core.validators
from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '__first__'),
        ('auth', '__first__'),
    ]

    operations = [
        RunPython(
            lambda *args, **kw: load_custom_sql("0001_collation")),

        migrations.CreateModel(
            name='BppUser',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                ('last_login', models.DateTimeField(default=django.utils.timezone.now, verbose_name='last login')),
                ('is_superuser', models.BooleanField(default=False, help_text='Designates that this user has all permissions without explicitly assigning them.', verbose_name='superuser status')),
                ('username', models.CharField(help_text='Required. 30 characters or fewer. Letters, digits and @/./+/-/_ only.', unique=True, max_length=30, verbose_name='username', validators=[django.core.validators.RegexValidator('^[\\w.@+-]+$', 'Enter a valid username.', 'invalid')])),
                ('first_name', models.CharField(max_length=30, verbose_name='first name', blank=True)),
                ('last_name', models.CharField(max_length=30, verbose_name='last name', blank=True)),
                ('email', models.EmailField(max_length=75, verbose_name='email address', blank=True)),
                ('is_staff', models.BooleanField(default=False, help_text='Designates whether the user can log into this admin site.', verbose_name='staff status')),
                ('is_active', models.BooleanField(default=True, help_text='Designates whether this user should be treated as active. Unselect this instead of deleting accounts.', verbose_name='active')),
                ('date_joined', models.DateTimeField(default=django.utils.timezone.now, verbose_name='date joined')),
                ('ostatnio_zmieniony', models.DateTimeField(auto_now=True, auto_now_add=True, null=True, db_index=True)),
                ('adnotacje', models.TextField(help_text=b'Pole do u\xc5\xbcytku wewn\xc4\x99trznego -\n    wpisane tu informacje nie s\xc4\x85 wy\xc5\x9bwietlane na stronach WWW dost\xc4\x99pnych\n    dla u\xc5\xbcytkownik\xc3\xb3w ko\xc5\x84cowych.', null=True, db_index=True, blank=True)),
                ('active_charmap_tab', models.IntegerField(default=0)),
                ('per_page', models.IntegerField(default=20, verbose_name=b'Ilo\xc5\x9b\xc4\x87 wy\xc5\x9bwietlanych rekord\xc3\xb3w na stronie')),
                ('multiseek_format', models.CharField(max_length=200, null=True, verbose_name=b'Ostatnio wybrany format wy\xc5\x9bwietlania w Multiseeku', blank=True)),
                ('multiseek_order_1', models.CharField(max_length=200, null=True, verbose_name=b'Ostatnio wybrane pole sortowania w Multiseeku', blank=True)),
                ('groups', models.ManyToManyField(to='auth.Group', verbose_name='groups', blank=True)),
                ('user_permissions', models.ManyToManyField(to='auth.Permission', verbose_name='user permissions', blank=True)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Autor',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('ostatnio_zmieniony', models.DateTimeField(auto_now=True, auto_now_add=True, null=True, db_index=True)),
                ('adnotacje', models.TextField(help_text=b'Pole do u\xc5\xbcytku wewn\xc4\x99trznego -\n    wpisane tu informacje nie s\xc4\x85 wy\xc5\x9bwietlane na stronach WWW dost\xc4\x99pnych\n    dla u\xc5\xbcytkownik\xc3\xb3w ko\xc5\x84cowych.', null=True, db_index=True, blank=True)),
                ('imiona', models.CharField(max_length=512, db_index=True)),
                ('nazwisko', models.CharField(max_length=256, db_index=True)),
                ('pokazuj_na_stronach_jednostek', models.BooleanField(default=True)),
                ('email', models.EmailField(max_length=128, null=True, verbose_name=b'E-mail', blank=True)),
                ('www', models.URLField(max_length=1024, null=True, verbose_name=b'WWW', blank=True)),
                ('urodzony', models.DateField(null=True, blank=True)),
                ('zmarl', models.DateField(null=True, blank=True)),
                ('poprzednie_nazwiska', models.CharField(help_text=b'Je\xc5\xbceli ten\n        autor(-ka) posiada nazwisko panie\xc5\x84skie, pod kt\xc3\xb3rym ukazywa\xc5\x82y\n        si\xc4\x99 publikacje lub zmienia\xc5\x82 nazwisko z innych powod\xc3\xb3w, wpisz tutaj\n        wszystkie poprzednie nazwiska, oddzielaj\xc4\x85c je przecinkami.', max_length=1024, null=True, db_index=True, blank=True)),
                ('search', SearchVectorField(default=b'', serialize=False, null=True, editable=False, db_index=True)),
                ('slug', autoslug.fields.AutoSlugField(unique=True, max_length=1024, editable=False)),
                ('sort', models.TextField()),
            ],
            options={
                'ordering': [b'sort'],
                'verbose_name': b'autor',
                'verbose_name_plural': b'autorzy',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Autor_Jednostka',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('rozpoczal_prace', models.DateField(db_index=True, null=True, verbose_name=b'Rozpocz\xc4\x85\xc5\x82 prac\xc4\x99', blank=True)),
                ('zakonczyl_prace', models.DateField(db_index=True, null=True, verbose_name=b'Zako\xc5\x84czy\xc5\x82 prac\xc4\x99', blank=True)),
                ('autor', models.ForeignKey(to='bpp.Autor', on_delete=models.CASCADE)),
            ],
            options={
                'ordering': [b'autor__nazwisko', b'jednostka__nazwa', b'rozpoczal_prace'],
                'verbose_name': b'powi\xc4\x85zanie autor-jednostka',
                'verbose_name_plural': b'powi\xc4\x85zania autor-jednostka',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Charakter_Formalny',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('nazwa', models.CharField(unique=True, max_length=512)),
                ('skrot', models.CharField(unique=True, max_length=128)),
                ('publikacja', models.BooleanField(default=False, help_text=b'Jest charakterem dla publikacji')),
                ('streszczenie', models.BooleanField(default=False, help_text=b'Jest charakterem dla streszcze\xc5\x84')),
            ],
            options={
                'ordering': [b'nazwa'],
                'verbose_name': b'charakter formalny',
                'verbose_name_plural': b'charaktery formalne',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Funkcja_Autora',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('nazwa', models.CharField(unique=True, max_length=512)),
                ('skrot', models.CharField(unique=True, max_length=128)),
            ],
            options={
                'ordering': [b'nazwa'],
                'verbose_name': b'funkcja w jednostce',
                'verbose_name_plural': b'funkcje w jednostkach',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='autor_jednostka',
            name='funkcja',
            field=models.ForeignKey(blank=True, to='bpp.Funkcja_Autora', null=True, on_delete=models.CASCADE),
            preserve_default=True,
        ),
        migrations.CreateModel(
            name='Jednostka',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('ostatnio_zmieniony', models.DateTimeField(auto_now=True, auto_now_add=True, null=True, db_index=True)),
                ('adnotacje', models.TextField(help_text=b'Pole do u\xc5\xbcytku wewn\xc4\x99trznego -\n    wpisane tu informacje nie s\xc4\x85 wy\xc5\x9bwietlane na stronach WWW dost\xc4\x99pnych\n    dla u\xc5\xbcytkownik\xc3\xb3w ko\xc5\x84cowych.', null=True, db_index=True, blank=True)),
                ('rozpoczecie_funkcjonowania', models.DateField(null=True, verbose_name=b'Rozpocz\xc4\x99cie funkcjonowania', blank=True)),
                ('zakonczenie_funkcjonowania', models.DateField(null=True, verbose_name=b'Zako\xc5\x84czenie funkcjonowania', blank=True)),
                ('nazwa', models.CharField(unique=True, max_length=512)),
                ('skrot', models.CharField(unique=True, max_length=128, verbose_name=b'Skr\xc3\xb3t')),
                ('opis', models.TextField(null=True, blank=True)),
                ('slug', autoslug.fields.AutoSlugField(unique=True, editable=False)),
                ('widoczna', models.BooleanField(default=True, db_index=True)),
                ('wchodzi_do_raportow', models.BooleanField(default=True, db_index=True, verbose_name=b'Wchodzi do raport\xc3\xb3w')),
                ('email', models.EmailField(max_length=128, null=True, verbose_name=b'E-mail', blank=True)),
                ('www', models.URLField(max_length=1024, null=True, verbose_name=b'WWW', blank=True)),
                ('search', SearchVectorField(default=b'', serialize=False, null=True, editable=False, db_index=True)),
            ],
            options={
                'ordering': ['nazwa'],
                'verbose_name': b'jednostka',
                'verbose_name_plural': b'jednostki',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='autor_jednostka',
            name='jednostka',
            field=models.ForeignKey(to='bpp.Jednostka', on_delete=models.CASCADE),
            preserve_default=True,
        ),
        migrations.AlterUniqueTogether(
            name='autor_jednostka',
            unique_together=set([('autor', 'jednostka', 'rozpoczal_prace')]),
        ),
        migrations.AddField(
            model_name='autor',
            name='jednostki',
            field=models.ManyToManyField(to='bpp.Jednostka', through='bpp.Autor_Jednostka'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='autor',
            name='aktualna_jednostka',
            field=models.ForeignKey(blank=True, to='bpp.Jednostka', null=True, on_delete=models.CASCADE),
            preserve_default=True,
        ),
        migrations.CreateModel(
            name='Jezyk',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('nazwa', models.CharField(unique=True, max_length=512)),
                ('skrot', models.CharField(unique=True, max_length=128)),
            ],
            options={
                'ordering': ['nazwa'],
                'verbose_name': b'j\xc4\x99zyk',
                'verbose_name_plural': b'j\xc4\x99zyki',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Opi_2012_Afiliacja_Do_Wydzialu',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('rok', models.IntegerField(db_index=True)),
                ('autor', models.ForeignKey(to='bpp.Autor', on_delete=models.CASCADE)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Opi_2012_Tytul_Cache',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('tytul_oryginalny_cache', models.TextField(db_index=True)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Patent',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('opis_bibliograficzny_cache', models.TextField(default=b'')),
                ('opis_bibliograficzny_autorzy_cache', ArrayField(models.TextField())),
                ('opis_bibliograficzny_zapisani_autorzy_cache', models.TextField(default=b'')),
                ('ostatnio_zmieniony', models.DateTimeField(auto_now=True, auto_now_add=True, null=True, db_index=True)),
                ('adnotacje', models.TextField(help_text=b'Pole do u\xc5\xbcytku wewn\xc4\x99trznego -\n    wpisane tu informacje nie s\xc4\x85 wy\xc5\x9bwietlane na stronach WWW dost\xc4\x99pnych\n    dla u\xc5\xbcytkownik\xc3\xb3w ko\xc5\x84cowych.', null=True, db_index=True, blank=True)),
                ('rok', models.IntegerField(help_text=b'Rok uwzgl\xc4\x99dniany przy wyszukiwaniu i raportach\n        KBN/MNiSW)', db_index=True)),
                ('www', models.URLField(max_length=1024, null=True, verbose_name=b'Adres WWW', blank=True)),
                ('afiliowana', models.BooleanField(default=False)),
                ('recenzowana', models.BooleanField(default=False)),
                ('impact_factor', models.DecimalField(default=Decimal('0.000'), max_digits=6, decimal_places=3, db_index=True)),
                ('punkty_kbn', models.DecimalField(default=Decimal('0.00'), verbose_name=b'Punkty KBN', max_digits=6, decimal_places=2, db_index=True)),
                ('index_copernicus', models.DecimalField(default=Decimal('0.00'), verbose_name=b'Index Copernicus', max_digits=6, decimal_places=2, db_index=True)),
                ('punktacja_wewnetrzna', models.DecimalField(default=Decimal('0.00'), verbose_name=b'Punktacja wewn\xc4\x99trzna', max_digits=6, decimal_places=2, db_index=True)),
                ('kc_impact_factor', models.DecimalField(decimal_places=2, default=None, max_digits=6, blank=True, help_text=b'Je\xc5\xbceli wpiszesz\n        warto\xc5\x9b\xc4\x87 w to pole, to zostanie ona u\xc5\xbcyta w raporcie dla Komisji\n        Centralnej w punkcie IXa tego raportu.', null=True, verbose_name=b'KC: Impact factor', db_index=True)),
                ('kc_punkty_kbn', models.DecimalField(decimal_places=2, default=None, max_digits=6, blank=True, help_text=b'Je\xc5\xbceli wpiszesz\n        warto\xc5\x9b\xc4\x87 w to pole, to zostanie ona u\xc5\xbcyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', null=True, verbose_name=b'KC: Punkty KBN', db_index=True)),
                ('kc_index_copernicus', models.DecimalField(decimal_places=2, default=None, max_digits=6, blank=True, help_text=b'Je\xc5\xbceli wpiszesz\n        warto\xc5\x9b\xc4\x87 w to pole, to zostanie ona u\xc5\xbcyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', null=True, verbose_name=b'KC: Index Copernicus')),
                ('weryfikacja_punktacji', models.BooleanField(default=False)),
                ('informacje', models.TextField(null=True, verbose_name=b'Informacje', blank=True)),
                ('szczegoly', models.CharField(help_text=b'Np. str. 23-45', max_length=512, null=True, verbose_name=b'Szczeg\xc3\xb3\xc5\x82y', blank=True)),
                ('uwagi', models.TextField(db_index=True, null=True, blank=True)),
                ('slowa_kluczowe', models.TextField(null=True, verbose_name=b'S\xc5\x82owa kluczowe', blank=True)),
                ('utworzono', models.DateTimeField(default=datetime.datetime(1970, 1, 1, 0, 0), verbose_name=b'Utworzono', auto_now_add=True)),
                ('search_index', SearchVectorField(default=b'', serialize=False, null=True, editable=False, db_index=True)),
                ('tytul_oryginalny_sort', models.TextField(default=b'', db_index=True)),
                ('tytul_oryginalny', models.TextField(verbose_name=b'Tytu\xc5\x82 oryginalny', db_index=True)),
                ('numer', models.CharField(max_length=255, null=True, blank=True)),
                ('z_dnia', models.DateField(null=True, blank=True)),
            ],
            options={
                'verbose_name': b'patent',
                'verbose_name_plural': b'patenty',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Patent_Autor',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('kolejnosc', models.IntegerField(default=0, verbose_name=b'Kolejno\xc5\x9b\xc4\x87')),
                ('zapisany_jako', models.CharField(max_length=512)),
                ('autor', models.ForeignKey(on_delete=models.CASCADE, to='bpp.Autor')),
                ('jednostka', models.ForeignKey(on_delete=models.CASCADE, to='bpp.Jednostka')),
            ],
            options={
                'ordering': ('kolejnosc',),
                'verbose_name': b'powi\xc4\x85zanie autora z patentem',
                'verbose_name_plural': b'powi\xc4\x85zania autor\xc3\xb3w z patentami',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='patent',
            name='autorzy',
            field=models.ManyToManyField(to='bpp.Autor', through='bpp.Patent_Autor'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='patent_autor',
            name='rekord',
            field=models.ForeignKey(on_delete=models.CASCADE, to='bpp.Patent'),
            preserve_default=True,
        ),
        migrations.CreateModel(
            name='Plec',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('nazwa', models.CharField(unique=True, max_length=512)),
                ('skrot', models.CharField(unique=True, max_length=128)),
            ],
            options={
                'verbose_name': b'p\xc5\x82e\xc4\x87',
                'verbose_name_plural': b'p\xc5\x82cie',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='autor',
            name='plec',
            field=models.ForeignKey(on_delete=models.CASCADE, blank=True, to='bpp.Plec', null=True),
            preserve_default=True,
        ),
        migrations.CreateModel(
            name='Praca_Doktorska',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('opis_bibliograficzny_cache', models.TextField(default=b'')),
                ('opis_bibliograficzny_autorzy_cache', ArrayField(models.TextField())),
                ('opis_bibliograficzny_zapisani_autorzy_cache', models.TextField(default=b'')),
                ('ostatnio_zmieniony', models.DateTimeField(auto_now=True, auto_now_add=True, null=True, db_index=True)),
                ('adnotacje', models.TextField(help_text=b'Pole do u\xc5\xbcytku wewn\xc4\x99trznego -\n    wpisane tu informacje nie s\xc4\x85 wy\xc5\x9bwietlane na stronach WWW dost\xc4\x99pnych\n    dla u\xc5\xbcytkownik\xc3\xb3w ko\xc5\x84cowych.', null=True, db_index=True, blank=True)),
                ('isbn', models.CharField(max_length=64, null=True, verbose_name=b'ISBN', blank=True)),
                ('e_isbn', models.CharField(max_length=64, null=True, verbose_name=b'E-ISBN', blank=True)),
                ('tytul_oryginalny', models.TextField(verbose_name=b'Tytu\xc5\x82 oryginalny', db_index=True)),
                ('tytul', models.TextField(db_index=True, null=True, verbose_name=b'Tytu\xc5\x82', blank=True)),
                ('rok', models.IntegerField(help_text=b'Rok uwzgl\xc4\x99dniany przy wyszukiwaniu i raportach\n        KBN/MNiSW)', db_index=True)),
                ('www', models.URLField(max_length=1024, null=True, verbose_name=b'Adres WWW', blank=True)),
                ('afiliowana', models.BooleanField(default=False)),
                ('recenzowana', models.BooleanField(default=False)),
                ('impact_factor', models.DecimalField(default=Decimal('0.000'), max_digits=6, decimal_places=3, db_index=True)),
                ('punkty_kbn', models.DecimalField(default=Decimal('0.00'), verbose_name=b'Punkty KBN', max_digits=6, decimal_places=2, db_index=True)),
                ('index_copernicus', models.DecimalField(default=Decimal('0.00'), verbose_name=b'Index Copernicus', max_digits=6, decimal_places=2, db_index=True)),
                ('punktacja_wewnetrzna', models.DecimalField(default=Decimal('0.00'), verbose_name=b'Punktacja wewn\xc4\x99trzna', max_digits=6, decimal_places=2, db_index=True)),
                ('kc_impact_factor', models.DecimalField(decimal_places=2, default=None, max_digits=6, blank=True, help_text=b'Je\xc5\xbceli wpiszesz\n        warto\xc5\x9b\xc4\x87 w to pole, to zostanie ona u\xc5\xbcyta w raporcie dla Komisji\n        Centralnej w punkcie IXa tego raportu.', null=True, verbose_name=b'KC: Impact factor', db_index=True)),
                ('kc_punkty_kbn', models.DecimalField(decimal_places=2, default=None, max_digits=6, blank=True, help_text=b'Je\xc5\xbceli wpiszesz\n        warto\xc5\x9b\xc4\x87 w to pole, to zostanie ona u\xc5\xbcyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', null=True, verbose_name=b'KC: Punkty KBN', db_index=True)),
                ('kc_index_copernicus', models.DecimalField(decimal_places=2, default=None, max_digits=6, blank=True, help_text=b'Je\xc5\xbceli wpiszesz\n        warto\xc5\x9b\xc4\x87 w to pole, to zostanie ona u\xc5\xbcyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', null=True, verbose_name=b'KC: Index Copernicus')),
                ('weryfikacja_punktacji', models.BooleanField(default=False)),
                ('informacje', models.TextField(null=True, verbose_name=b'Informacje', blank=True)),
                ('szczegoly', models.CharField(help_text=b'Np. str. 23-45', max_length=512, null=True, verbose_name=b'Szczeg\xc3\xb3\xc5\x82y', blank=True)),
                ('uwagi', models.TextField(db_index=True, null=True, blank=True)),
                ('slowa_kluczowe', models.TextField(null=True, verbose_name=b'S\xc5\x82owa kluczowe', blank=True)),
                ('utworzono', models.DateTimeField(default=datetime.datetime(1970, 1, 1, 0, 0), verbose_name=b'Utworzono', auto_now_add=True)),
                ('search_index', SearchVectorField(default=b'', serialize=False, null=True, editable=False, db_index=True)),
                ('tytul_oryginalny_sort', models.TextField(default=b'', db_index=True)),
                ('miejsce_i_rok', models.CharField(help_text=b'Przyk\xc5\x82adowo:\n        Warszawa 2012. Wpisz prosz\xc4\x99 najpierw miejsce potem rok; oddziel\n        spacj\xc4\x85.', max_length=256, null=True, blank=True)),
                ('wydawnictwo', models.CharField(max_length=256, null=True, blank=True)),
                ('redakcja', models.TextField(null=True, blank=True)),
                ('autor', models.ForeignKey(on_delete=models.CASCADE, to='bpp.Autor')),
                ('jednostka', models.ForeignKey(on_delete=models.CASCADE, to='bpp.Jednostka')),
                ('jezyk', models.ForeignKey(on_delete=models.CASCADE, verbose_name=b'J\xc4\x99zyk', to='bpp.Jezyk')),
            ],
            options={
                'verbose_name': b'praca doktorska',
                'verbose_name_plural': b'prace doktorskie',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Praca_Habilitacyjna',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('opis_bibliograficzny_cache', models.TextField(default=b'')),
                ('opis_bibliograficzny_autorzy_cache', ArrayField(models.TextField())),
                ('opis_bibliograficzny_zapisani_autorzy_cache', models.TextField(default=b'')),
                ('ostatnio_zmieniony', models.DateTimeField(auto_now=True, auto_now_add=True, null=True, db_index=True)),
                ('adnotacje', models.TextField(help_text=b'Pole do u\xc5\xbcytku wewn\xc4\x99trznego -\n    wpisane tu informacje nie s\xc4\x85 wy\xc5\x9bwietlane na stronach WWW dost\xc4\x99pnych\n    dla u\xc5\xbcytkownik\xc3\xb3w ko\xc5\x84cowych.', null=True, db_index=True, blank=True)),
                ('isbn', models.CharField(max_length=64, null=True, verbose_name=b'ISBN', blank=True)),
                ('e_isbn', models.CharField(max_length=64, null=True, verbose_name=b'E-ISBN', blank=True)),
                ('tytul_oryginalny', models.TextField(verbose_name=b'Tytu\xc5\x82 oryginalny', db_index=True)),
                ('tytul', models.TextField(db_index=True, null=True, verbose_name=b'Tytu\xc5\x82', blank=True)),
                ('rok', models.IntegerField(help_text=b'Rok uwzgl\xc4\x99dniany przy wyszukiwaniu i raportach\n        KBN/MNiSW)', db_index=True)),
                ('www', models.URLField(max_length=1024, null=True, verbose_name=b'Adres WWW', blank=True)),
                ('afiliowana', models.BooleanField(default=False)),
                ('recenzowana', models.BooleanField(default=False)),
                ('impact_factor', models.DecimalField(default=Decimal('0.000'), max_digits=6, decimal_places=3, db_index=True)),
                ('punkty_kbn', models.DecimalField(default=Decimal('0.00'), verbose_name=b'Punkty KBN', max_digits=6, decimal_places=2, db_index=True)),
                ('index_copernicus', models.DecimalField(default=Decimal('0.00'), verbose_name=b'Index Copernicus', max_digits=6, decimal_places=2, db_index=True)),
                ('punktacja_wewnetrzna', models.DecimalField(default=Decimal('0.00'), verbose_name=b'Punktacja wewn\xc4\x99trzna', max_digits=6, decimal_places=2, db_index=True)),
                ('kc_impact_factor', models.DecimalField(decimal_places=2, default=None, max_digits=6, blank=True, help_text=b'Je\xc5\xbceli wpiszesz\n        warto\xc5\x9b\xc4\x87 w to pole, to zostanie ona u\xc5\xbcyta w raporcie dla Komisji\n        Centralnej w punkcie IXa tego raportu.', null=True, verbose_name=b'KC: Impact factor', db_index=True)),
                ('kc_punkty_kbn', models.DecimalField(decimal_places=2, default=None, max_digits=6, blank=True, help_text=b'Je\xc5\xbceli wpiszesz\n        warto\xc5\x9b\xc4\x87 w to pole, to zostanie ona u\xc5\xbcyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', null=True, verbose_name=b'KC: Punkty KBN', db_index=True)),
                ('kc_index_copernicus', models.DecimalField(decimal_places=2, default=None, max_digits=6, blank=True, help_text=b'Je\xc5\xbceli wpiszesz\n        warto\xc5\x9b\xc4\x87 w to pole, to zostanie ona u\xc5\xbcyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', null=True, verbose_name=b'KC: Index Copernicus')),
                ('weryfikacja_punktacji', models.BooleanField(default=False)),
                ('informacje', models.TextField(null=True, verbose_name=b'Informacje', blank=True)),
                ('szczegoly', models.CharField(help_text=b'Np. str. 23-45', max_length=512, null=True, verbose_name=b'Szczeg\xc3\xb3\xc5\x82y', blank=True)),
                ('uwagi', models.TextField(db_index=True, null=True, blank=True)),
                ('slowa_kluczowe', models.TextField(null=True, verbose_name=b'S\xc5\x82owa kluczowe', blank=True)),
                ('utworzono', models.DateTimeField(default=datetime.datetime(1970, 1, 1, 0, 0), verbose_name=b'Utworzono', auto_now_add=True)),
                ('search_index', SearchVectorField(default=b'', serialize=False, null=True, editable=False, db_index=True)),
                ('tytul_oryginalny_sort', models.TextField(default=b'', db_index=True)),
                ('miejsce_i_rok', models.CharField(help_text=b'Przyk\xc5\x82adowo:\n        Warszawa 2012. Wpisz prosz\xc4\x99 najpierw miejsce potem rok; oddziel\n        spacj\xc4\x85.', max_length=256, null=True, blank=True)),
                ('wydawnictwo', models.CharField(max_length=256, null=True, blank=True)),
                ('redakcja', models.TextField(null=True, blank=True)),
                ('autor', models.ForeignKey(on_delete=models.CASCADE, to='bpp.Autor')),
                ('jednostka', models.ForeignKey(on_delete=models.CASCADE, to='bpp.Jednostka')),
                ('jezyk', models.ForeignKey(on_delete=models.CASCADE, verbose_name=b'J\xc4\x99zyk', to='bpp.Jezyk')),
            ],
            options={
                'verbose_name': b'praca habilitacyjna',
                'verbose_name_plural': b'prace habilitacyjne',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Publikacja_Habilitacyjna',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('kolejnosc', models.IntegerField(default=0, verbose_name=b'Kolejno\xc5\x9b\xc4\x87')),
                ('object_id', models.PositiveIntegerField()),
                ('content_type', models.ForeignKey(on_delete=models.CASCADE, to='contenttypes.ContentType')),
                ('praca_habilitacyjna', models.ForeignKey(on_delete=models.CASCADE, to='bpp.Praca_Habilitacyjna')),
            ],
            options={
                'ordering': ('kolejnosc',),
                'verbose_name': b'powi\xc4\x85zanie publikacji z habilitacj\xc4\x85',
                'verbose_name_plural': b'powi\xc4\x85zania publikacji z habilitacj\xc4\x85',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Punktacja_Zrodla',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('impact_factor', models.DecimalField(default=Decimal('0.000'), max_digits=6, decimal_places=3, db_index=True)),
                ('punkty_kbn', models.DecimalField(default=Decimal('0.00'), verbose_name=b'Punkty KBN', max_digits=6, decimal_places=2, db_index=True)),
                ('index_copernicus', models.DecimalField(default=Decimal('0.00'), verbose_name=b'Index Copernicus', max_digits=6, decimal_places=2, db_index=True)),
                ('punktacja_wewnetrzna', models.DecimalField(default=Decimal('0.00'), verbose_name=b'Punktacja wewn\xc4\x99trzna', max_digits=6, decimal_places=2, db_index=True)),
                ('kc_impact_factor', models.DecimalField(decimal_places=2, default=None, max_digits=6, blank=True, help_text=b'Je\xc5\xbceli wpiszesz\n        warto\xc5\x9b\xc4\x87 w to pole, to zostanie ona u\xc5\xbcyta w raporcie dla Komisji\n        Centralnej w punkcie IXa tego raportu.', null=True, verbose_name=b'KC: Impact factor', db_index=True)),
                ('kc_punkty_kbn', models.DecimalField(decimal_places=2, default=None, max_digits=6, blank=True, help_text=b'Je\xc5\xbceli wpiszesz\n        warto\xc5\x9b\xc4\x87 w to pole, to zostanie ona u\xc5\xbcyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', null=True, verbose_name=b'KC: Punkty KBN', db_index=True)),
                ('kc_index_copernicus', models.DecimalField(decimal_places=2, default=None, max_digits=6, blank=True, help_text=b'Je\xc5\xbceli wpiszesz\n        warto\xc5\x9b\xc4\x87 w to pole, to zostanie ona u\xc5\xbcyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', null=True, verbose_name=b'KC: Index Copernicus')),
                ('rok', models.IntegerField()),
            ],
            options={
                'ordering': ['zrodlo__nazwa', 'rok'],
                'verbose_name': b'punktacja \xc5\xbar\xc3\xb3d\xc5\x82a',
                'verbose_name_plural': b'punktacja \xc5\xbar\xc3\xb3d\xc5\x82a',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Redakcja_Zrodla',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('od_roku', models.IntegerField()),
                ('do_roku', models.IntegerField(null=True, blank=True)),
                ('redaktor', models.ForeignKey(on_delete=models.CASCADE, to='bpp.Autor')),
            ],
            options={
                'verbose_name': b'redaktor \xc5\xbar\xc3\xb3d\xc5\x82a',
                'verbose_name_plural': b'redaktorzy \xc5\xbar\xc3\xb3d\xc5\x82a',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Rodzaj_Zrodla',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('nazwa', models.CharField(unique=True, max_length=512)),
            ],
            options={
                'verbose_name': b'rodzaj \xc5\xbar\xc3\xb3d\xc5\x82a',
                'verbose_name_plural': b'rodzaje \xc5\xbar\xc3\xb3de\xc5\x82',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Status_Korekty',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('nazwa', models.CharField(unique=True, max_length=512)),
            ],
            options={
                'verbose_name': b'status korekty',
                'verbose_name_plural': b'statusy korekty',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='praca_habilitacyjna',
            name='status_korekty',
            field=models.ForeignKey(on_delete=models.CASCADE, default=1, to='bpp.Status_Korekty'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='praca_doktorska',
            name='status_korekty',
            field=models.ForeignKey(on_delete=models.CASCADE, default=1, to='bpp.Status_Korekty'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='patent',
            name='status_korekty',
            field=models.ForeignKey(on_delete=models.CASCADE, default=1, to='bpp.Status_Korekty'),
            preserve_default=True,
        ),
        migrations.CreateModel(
            name='Typ_KBN',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('nazwa', models.CharField(unique=True, max_length=512)),
                ('skrot', models.CharField(unique=True, max_length=128)),
            ],
            options={
                'ordering': ['nazwa'],
                'verbose_name': b'typ KBN',
                'verbose_name_plural': b'typy KBN',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='praca_habilitacyjna',
            name='typ_kbn',
            field=models.ForeignKey(on_delete=models.CASCADE, verbose_name=b'Typ KBN', to='bpp.Typ_KBN'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='praca_doktorska',
            name='typ_kbn',
            field=models.ForeignKey(on_delete=models.CASCADE, verbose_name=b'Typ KBN', to='bpp.Typ_KBN'),
            preserve_default=True,
        ),
        migrations.CreateModel(
            name='Typ_Odpowiedzialnosci',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('nazwa', models.CharField(unique=True, max_length=512)),
                ('skrot', models.CharField(unique=True, max_length=128)),
            ],
            options={
                'ordering': [b'nazwa'],
                'verbose_name': b'typ odpowiedzialno\xc5\x9bci autora',
                'verbose_name_plural': b'typy odpowiedzialno\xc5\x9bci autor\xc3\xb3w',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='patent_autor',
            name='typ_odpowiedzialnosci',
            field=models.ForeignKey(on_delete=models.CASCADE, verbose_name=b'Typ odpowiedzialno\xc5\x9bci', to='bpp.Typ_Odpowiedzialnosci'),
            preserve_default=True,
        ),
        migrations.AlterUniqueTogether(
            name='patent_autor',
            unique_together=set([('rekord', 'autor', 'typ_odpowiedzialnosci', 'kolejnosc')]),
        ),
        migrations.CreateModel(
            name='Tytul',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('nazwa', models.CharField(unique=True, max_length=512)),
                ('skrot', models.CharField(unique=True, max_length=128)),
            ],
            options={
                'verbose_name': b'tytu\xc5\x82',
                'verbose_name_plural': b'tytu\xc5\x82y',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='autor',
            name='tytul',
            field=models.ForeignKey(on_delete=models.CASCADE, blank=True, to='bpp.Tytul', null=True),
            preserve_default=True,
        ),
        migrations.CreateModel(
            name='Uczelnia',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('ostatnio_zmieniony', models.DateTimeField(auto_now=True, auto_now_add=True, null=True, db_index=True)),
                ('adnotacje', models.TextField(help_text=b'Pole do u\xc5\xbcytku wewn\xc4\x99trznego -\n    wpisane tu informacje nie s\xc4\x85 wy\xc5\x9bwietlane na stronach WWW dost\xc4\x99pnych\n    dla u\xc5\xbcytkownik\xc3\xb3w ko\xc5\x84cowych.', null=True, db_index=True, blank=True)),
                ('nazwa', models.CharField(unique=True, max_length=512)),
                ('skrot', models.CharField(unique=True, max_length=128)),
                ('nazwa_dopelniacz_field', models.CharField(max_length=512, null=True, verbose_name='Nazwa w dope\u0142niaczu', blank=True)),
                ('slug', autoslug.fields.AutoSlugField(unique=True, editable=False)),
                ('logo_www', models.ImageField(help_text=b'Plik w formacie bitmapowym, np. JPEG lub PNG,\n        w rozdzielczo\xc5\x9bci maks. 100x100', upload_to=b'logo', null=True, verbose_name=b'Logo na stron\xc4\x99 WWW', blank=True)),
                ('logo_svg', models.FileField(upload_to=b'logo_svg', null=True, verbose_name=b'Logo wektorowe (SVG)', blank=True)),
                ('favicon_ico', models.FileField(upload_to=b'favicon', null=True, verbose_name=b'Ikona ulubionych (favicon)', blank=True)),
            ],
            options={
                'verbose_name': b'uczelnia',
                'verbose_name_plural': b'uczelnie',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Wydawnictwo_Ciagle',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('opis_bibliograficzny_cache', models.TextField(default=b'')),
                ('opis_bibliograficzny_autorzy_cache', ArrayField(models.TextField())),
                ('opis_bibliograficzny_zapisani_autorzy_cache', models.TextField(default=b'')),
                ('ostatnio_zmieniony', models.DateTimeField(auto_now=True, auto_now_add=True, null=True, db_index=True)),
                ('adnotacje', models.TextField(help_text=b'Pole do u\xc5\xbcytku wewn\xc4\x99trznego -\n    wpisane tu informacje nie s\xc4\x85 wy\xc5\x9bwietlane na stronach WWW dost\xc4\x99pnych\n    dla u\xc5\xbcytkownik\xc3\xb3w ko\xc5\x84cowych.', null=True, db_index=True, blank=True)),
                ('issn', models.CharField(max_length=32, null=True, verbose_name=b'ISSN', blank=True)),
                ('e_issn', models.CharField(max_length=32, null=True, verbose_name=b'e-ISSN', blank=True)),
                ('tytul_oryginalny', models.TextField(verbose_name=b'Tytu\xc5\x82 oryginalny', db_index=True)),
                ('tytul', models.TextField(db_index=True, null=True, verbose_name=b'Tytu\xc5\x82', blank=True)),
                ('rok', models.IntegerField(help_text=b'Rok uwzgl\xc4\x99dniany przy wyszukiwaniu i raportach\n        KBN/MNiSW)', db_index=True)),
                ('www', models.URLField(max_length=1024, null=True, verbose_name=b'Adres WWW', blank=True)),
                ('afiliowana', models.BooleanField(default=False)),
                ('recenzowana', models.BooleanField(default=False)),
                ('impact_factor', models.DecimalField(default=Decimal('0.000'), max_digits=6, decimal_places=3, db_index=True)),
                ('punkty_kbn', models.DecimalField(default=Decimal('0.00'), verbose_name=b'Punkty KBN', max_digits=6, decimal_places=2, db_index=True)),
                ('index_copernicus', models.DecimalField(default=Decimal('0.00'), verbose_name=b'Index Copernicus', max_digits=6, decimal_places=2, db_index=True)),
                ('punktacja_wewnetrzna', models.DecimalField(default=Decimal('0.00'), verbose_name=b'Punktacja wewn\xc4\x99trzna', max_digits=6, decimal_places=2, db_index=True)),
                ('kc_impact_factor', models.DecimalField(decimal_places=2, default=None, max_digits=6, blank=True, help_text=b'Je\xc5\xbceli wpiszesz\n        warto\xc5\x9b\xc4\x87 w to pole, to zostanie ona u\xc5\xbcyta w raporcie dla Komisji\n        Centralnej w punkcie IXa tego raportu.', null=True, verbose_name=b'KC: Impact factor', db_index=True)),
                ('kc_punkty_kbn', models.DecimalField(decimal_places=2, default=None, max_digits=6, blank=True, help_text=b'Je\xc5\xbceli wpiszesz\n        warto\xc5\x9b\xc4\x87 w to pole, to zostanie ona u\xc5\xbcyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', null=True, verbose_name=b'KC: Punkty KBN', db_index=True)),
                ('kc_index_copernicus', models.DecimalField(decimal_places=2, default=None, max_digits=6, blank=True, help_text=b'Je\xc5\xbceli wpiszesz\n        warto\xc5\x9b\xc4\x87 w to pole, to zostanie ona u\xc5\xbcyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', null=True, verbose_name=b'KC: Index Copernicus')),
                ('weryfikacja_punktacji', models.BooleanField(default=False)),
                ('informacje', models.TextField(null=True, verbose_name=b'Informacje', blank=True)),
                ('szczegoly', models.CharField(help_text=b'Np. str. 23-45', max_length=512, null=True, verbose_name=b'Szczeg\xc3\xb3\xc5\x82y', blank=True)),
                ('uwagi', models.TextField(db_index=True, null=True, blank=True)),
                ('slowa_kluczowe', models.TextField(null=True, verbose_name=b'S\xc5\x82owa kluczowe', blank=True)),
                ('utworzono', models.DateTimeField(default=datetime.datetime(1970, 1, 1, 0, 0), verbose_name=b'Utworzono', auto_now_add=True)),
                ('search_index', SearchVectorField(default=b'', serialize=False, null=True, editable=False, db_index=True)),
                ('tytul_oryginalny_sort', models.TextField(default=b'', db_index=True)),
                ('uzupelnij_punktacje', models.BooleanField(default=False)),
                ('charakter_formalny', models.ForeignKey(on_delete=models.CASCADE, verbose_name=b'Charakter formalny', to='bpp.Charakter_Formalny')),
                ('jezyk', models.ForeignKey(on_delete=models.CASCADE, verbose_name=b'J\xc4\x99zyk', to='bpp.Jezyk')),
                ('status_korekty', models.ForeignKey(on_delete=models.CASCADE, default=1, to='bpp.Status_Korekty')),
                ('typ_kbn', models.ForeignKey(on_delete=models.CASCADE, verbose_name=b'Typ KBN', to='bpp.Typ_KBN')),
            ],
            options={
                'verbose_name': b'wydawnictwo ci\xc4\x85g\xc5\x82e',
                'verbose_name_plural': b'wydawnictwa ci\xc4\x85g\xc5\x82e',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Wydawnictwo_Ciagle_Autor',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('kolejnosc', models.IntegerField(default=0, verbose_name=b'Kolejno\xc5\x9b\xc4\x87')),
                ('zapisany_jako', models.CharField(max_length=512)),
                ('autor', models.ForeignKey(on_delete=models.CASCADE, to='bpp.Autor')),
                ('jednostka', models.ForeignKey(on_delete=models.CASCADE, to='bpp.Jednostka')),
            ],
            options={
                'ordering': (b'kolejnosc',),
                'verbose_name': b'powi\xc4\x85zanie autora z wyd. ci\xc4\x85g\xc5\x82ym',
                'verbose_name_plural': b'powi\xc4\x85zania autor\xc3\xb3w z wyd. ci\xc4\x85g\xc5\x82ymi',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='autorzy',
            field=models.ManyToManyField(to='bpp.Autor', through='bpp.Wydawnictwo_Ciagle_Autor'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle_autor',
            name='rekord',
            field=models.ForeignKey(on_delete=models.CASCADE, to='bpp.Wydawnictwo_Ciagle'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle_autor',
            name='typ_odpowiedzialnosci',
            field=models.ForeignKey(on_delete=models.CASCADE, verbose_name=b'Typ odpowiedzialno\xc5\x9bci', to='bpp.Typ_Odpowiedzialnosci'),
            preserve_default=True,
        ),
        migrations.AlterUniqueTogether(
            name='wydawnictwo_ciagle_autor',
            unique_together=set([('rekord', 'autor', 'typ_odpowiedzialnosci', 'kolejnosc')]),
        ),
        migrations.CreateModel(
            name='Wydawnictwo_Zwarte',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('opis_bibliograficzny_cache', models.TextField(default=b'')),
                ('opis_bibliograficzny_autorzy_cache', ArrayField(models.TextField())),
                ('opis_bibliograficzny_zapisani_autorzy_cache', models.TextField(default=b'')),
                ('ostatnio_zmieniony', models.DateTimeField(auto_now=True, auto_now_add=True, null=True, db_index=True)),
                ('adnotacje', models.TextField(help_text=b'Pole do u\xc5\xbcytku wewn\xc4\x99trznego -\n    wpisane tu informacje nie s\xc4\x85 wy\xc5\x9bwietlane na stronach WWW dost\xc4\x99pnych\n    dla u\xc5\xbcytkownik\xc3\xb3w ko\xc5\x84cowych.', null=True, db_index=True, blank=True)),
                ('isbn', models.CharField(max_length=64, null=True, verbose_name=b'ISBN', blank=True)),
                ('e_isbn', models.CharField(max_length=64, null=True, verbose_name=b'E-ISBN', blank=True)),
                ('tytul_oryginalny', models.TextField(verbose_name=b'Tytu\xc5\x82 oryginalny', db_index=True)),
                ('tytul', models.TextField(db_index=True, null=True, verbose_name=b'Tytu\xc5\x82', blank=True)),
                ('rok', models.IntegerField(help_text=b'Rok uwzgl\xc4\x99dniany przy wyszukiwaniu i raportach\n        KBN/MNiSW)', db_index=True)),
                ('www', models.URLField(max_length=1024, null=True, verbose_name=b'Adres WWW', blank=True)),
                ('afiliowana', models.BooleanField(default=False)),
                ('recenzowana', models.BooleanField(default=False)),
                ('impact_factor', models.DecimalField(default=Decimal('0.000'), max_digits=6, decimal_places=3, db_index=True)),
                ('punkty_kbn', models.DecimalField(default=Decimal('0.00'), verbose_name=b'Punkty KBN', max_digits=6, decimal_places=2, db_index=True)),
                ('index_copernicus', models.DecimalField(default=Decimal('0.00'), verbose_name=b'Index Copernicus', max_digits=6, decimal_places=2, db_index=True)),
                ('punktacja_wewnetrzna', models.DecimalField(default=Decimal('0.00'), verbose_name=b'Punktacja wewn\xc4\x99trzna', max_digits=6, decimal_places=2, db_index=True)),
                ('kc_impact_factor', models.DecimalField(decimal_places=2, default=None, max_digits=6, blank=True, help_text=b'Je\xc5\xbceli wpiszesz\n        warto\xc5\x9b\xc4\x87 w to pole, to zostanie ona u\xc5\xbcyta w raporcie dla Komisji\n        Centralnej w punkcie IXa tego raportu.', null=True, verbose_name=b'KC: Impact factor', db_index=True)),
                ('kc_punkty_kbn', models.DecimalField(decimal_places=2, default=None, max_digits=6, blank=True, help_text=b'Je\xc5\xbceli wpiszesz\n        warto\xc5\x9b\xc4\x87 w to pole, to zostanie ona u\xc5\xbcyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', null=True, verbose_name=b'KC: Punkty KBN', db_index=True)),
                ('kc_index_copernicus', models.DecimalField(decimal_places=2, default=None, max_digits=6, blank=True, help_text=b'Je\xc5\xbceli wpiszesz\n        warto\xc5\x9b\xc4\x87 w to pole, to zostanie ona u\xc5\xbcyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', null=True, verbose_name=b'KC: Index Copernicus')),
                ('weryfikacja_punktacji', models.BooleanField(default=False)),
                ('informacje', models.TextField(null=True, verbose_name=b'Informacje', blank=True)),
                ('szczegoly', models.CharField(help_text=b'Np. str. 23-45', max_length=512, null=True, verbose_name=b'Szczeg\xc3\xb3\xc5\x82y', blank=True)),
                ('uwagi', models.TextField(db_index=True, null=True, blank=True)),
                ('slowa_kluczowe', models.TextField(null=True, verbose_name=b'S\xc5\x82owa kluczowe', blank=True)),
                ('utworzono', models.DateTimeField(default=datetime.datetime(1970, 1, 1, 0, 0), verbose_name=b'Utworzono', auto_now_add=True)),
                ('search_index', SearchVectorField(default=b'', serialize=False, null=True, editable=False, db_index=True)),
                ('tytul_oryginalny_sort', models.TextField(default=b'', db_index=True)),
                ('miejsce_i_rok', models.CharField(help_text=b'Przyk\xc5\x82adowo:\n        Warszawa 2012. Wpisz prosz\xc4\x99 najpierw miejsce potem rok; oddziel\n        spacj\xc4\x85.', max_length=256, null=True, blank=True)),
                ('wydawnictwo', models.CharField(max_length=256, null=True, blank=True)),
                ('redakcja', models.TextField(null=True, blank=True)),
                ('liczba_znakow_wydawniczych', models.IntegerField(null=True, verbose_name=b'Liczba znak\xc3\xb3w wydawniczych', blank=True)),
                ('charakter_formalny', models.ForeignKey(on_delete=models.CASCADE, verbose_name=b'Charakter formalny', to='bpp.Charakter_Formalny')),
                ('jezyk', models.ForeignKey(on_delete=models.CASCADE, verbose_name=b'J\xc4\x99zyk', to='bpp.Jezyk')),
                ('status_korekty', models.ForeignKey(on_delete=models.CASCADE, default=1, to='bpp.Status_Korekty')),
                ('typ_kbn', models.ForeignKey(on_delete=models.CASCADE, verbose_name=b'Typ KBN', to='bpp.Typ_KBN')),
                ('wydawnictwo_nadrzedne', models.ForeignKey(on_delete=models.CASCADE, blank=True, to='bpp.Wydawnictwo_Zwarte', help_text=b'Je\xc5\xbceli dodajesz rozdzia\xc5\x82,\n        tu wybierz prac\xc4\x99, w ramach kt\xc3\xb3rej dany rozdzia\xc5\x82 wyst\xc4\x99puje.', null=True)),
            ],
            options={
                'verbose_name': b'wydawnictwo zwarte',
                'verbose_name_plural': b'wydawnictwa zwarte',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='opi_2012_tytul_cache',
            name='wydawnictwo_zwarte',
            field=models.ForeignKey(on_delete=models.CASCADE, to='bpp.Wydawnictwo_Zwarte'),
            preserve_default=True,
        ),
        migrations.CreateModel(
            name='Wydawnictwo_Zwarte_Autor',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('kolejnosc', models.IntegerField(default=0, verbose_name=b'Kolejno\xc5\x9b\xc4\x87')),
                ('zapisany_jako', models.CharField(max_length=512)),
                ('autor', models.ForeignKey(on_delete=models.CASCADE, to='bpp.Autor')),
                ('jednostka', models.ForeignKey(on_delete=models.CASCADE, to='bpp.Jednostka')),
            ],
            options={
                'ordering': (b'kolejnosc',),
                'verbose_name': b'powi\xc4\x85zanie autora z wyd. zwartym',
                'verbose_name_plural': b'powi\xc4\x85zania autor\xc3\xb3w z wyd. zwartymi',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='autorzy',
            field=models.ManyToManyField(to='bpp.Autor', through='bpp.Wydawnictwo_Zwarte_Autor'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte_autor',
            name='rekord',
            field=models.ForeignKey(on_delete=models.CASCADE, to='bpp.Wydawnictwo_Zwarte'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte_autor',
            name='typ_odpowiedzialnosci',
            field=models.ForeignKey(on_delete=models.CASCADE, verbose_name=b'Typ odpowiedzialno\xc5\x9bci', to='bpp.Typ_Odpowiedzialnosci'),
            preserve_default=True,
        ),
        migrations.AlterUniqueTogether(
            name='wydawnictwo_zwarte_autor',
            unique_together=set([('rekord', 'autor', 'typ_odpowiedzialnosci', 'kolejnosc')]),
        ),
        migrations.CreateModel(
            name='Wydzial',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('ostatnio_zmieniony', models.DateTimeField(auto_now=True, auto_now_add=True, null=True, db_index=True)),
                ('adnotacje', models.TextField(help_text=b'Pole do u\xc5\xbcytku wewn\xc4\x99trznego -\n    wpisane tu informacje nie s\xc4\x85 wy\xc5\x9bwietlane na stronach WWW dost\xc4\x99pnych\n    dla u\xc5\xbcytkownik\xc3\xb3w ko\xc5\x84cowych.', null=True, db_index=True, blank=True)),
                ('rozpoczecie_funkcjonowania', models.DateField(null=True, verbose_name=b'Rozpocz\xc4\x99cie funkcjonowania', blank=True)),
                ('zakonczenie_funkcjonowania', models.DateField(null=True, verbose_name=b'Zako\xc5\x84czenie funkcjonowania', blank=True)),
                ('nazwa', models.CharField(unique=True, max_length=512)),
                ('skrot', models.CharField(unique=True, max_length=4, verbose_name=b'Skr\xc3\xb3t')),
                ('opis', models.TextField(null=True, blank=True)),
                ('slug', autoslug.fields.AutoSlugField(unique=True, max_length=512, editable=False)),
                ('kolejnosc', models.IntegerField(default=0, verbose_name=b'Kolejno\xc5\x9b\xc4\x87')),
                ('widoczny', models.BooleanField(default=True)),
                ('uczelnia', models.ForeignKey(on_delete=models.CASCADE, to='bpp.Uczelnia')),
            ],
            options={
                'ordering': [b'kolejnosc', b'skrot'],
                'verbose_name': b'wydzia\xc5\x82',
                'verbose_name_plural': b'wydzia\xc5\x82y',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='opi_2012_afiliacja_do_wydzialu',
            name='wydzial',
            field=models.ForeignKey(on_delete=models.CASCADE, to='bpp.Wydzial'),
            preserve_default=True,
        ),
        migrations.AlterUniqueTogether(
            name='opi_2012_afiliacja_do_wydzialu',
            unique_together=set([('autor', 'wydzial', 'rok')]),
        ),
        migrations.AddField(
            model_name='jednostka',
            name='wydzial',
            field=models.ForeignKey(on_delete=models.CASCADE, verbose_name=b'Wydzia\xc5\x82', to='bpp.Wydzial'),
            preserve_default=True,
        ),
        migrations.CreateModel(
            name='Zasieg_Zrodla',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('nazwa', models.CharField(unique=True, max_length=512)),
            ],
            options={
                'verbose_name': b'zasi\xc4\x99g \xc5\xbar\xc3\xb3d\xc5\x82a',
                'verbose_name_plural': b'zasi\xc4\x99g \xc5\xbar\xc3\xb3de\xc5\x82',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Zrodlo',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('ostatnio_zmieniony', models.DateTimeField(auto_now=True, auto_now_add=True, null=True, db_index=True)),
                ('adnotacje', models.TextField(help_text=b'Pole do u\xc5\xbcytku wewn\xc4\x99trznego -\n    wpisane tu informacje nie s\xc4\x85 wy\xc5\x9bwietlane na stronach WWW dost\xc4\x99pnych\n    dla u\xc5\xbcytkownik\xc3\xb3w ko\xc5\x84cowych.', null=True, db_index=True, blank=True)),
                ('issn', models.CharField(max_length=32, null=True, verbose_name=b'ISSN', blank=True)),
                ('e_issn', models.CharField(max_length=32, null=True, verbose_name=b'e-ISSN', blank=True)),
                ('nazwa', models.CharField(max_length=1024, db_index=True)),
                ('skrot', models.CharField(max_length=512, verbose_name=b'Skr\xc3\xb3t')),
                ('www', models.URLField(max_length=1024, null=True, verbose_name=b'WWW', blank=True)),
                ('poprzednia_nazwa', models.CharField(db_index=True, max_length=1024, null=True, verbose_name=b'Poprzedni tytu\xc5\x82', blank=True)),
                ('search', SearchVectorField(default=b'', serialize=False, null=True, editable=False, db_index=True)),
                ('slug', autoslug.fields.AutoSlugField(unique=True, editable=False)),
                ('rodzaj', models.ForeignKey(on_delete=models.CASCADE, to='bpp.Rodzaj_Zrodla')),
                ('zasieg', models.ForeignKey(on_delete=models.CASCADE, default=None, blank=True, to='bpp.Zasieg_Zrodla', null=True)),
            ],
            options={
                'ordering': [b'nazwa'],
                'verbose_name': b'\xc5\xbar\xc3\xb3d\xc5\x82o',
                'verbose_name_plural': b'\xc5\xbar\xc3\xb3d\xc5\x82a',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='zrodlo',
            field=models.ForeignKey(on_delete=models.CASCADE, verbose_name=b'\xc5\xb9r\xc3\xb3d\xc5\x82o', to='bpp.Zrodlo', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='redakcja_zrodla',
            name='zrodlo',
            field=models.ForeignKey(on_delete=models.CASCADE, to='bpp.Zrodlo'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='punktacja_zrodla',
            name='zrodlo',
            field=models.ForeignKey(on_delete=models.CASCADE, to='bpp.Zrodlo'),
            preserve_default=True,
        ),
        migrations.AlterUniqueTogether(
            name='punktacja_zrodla',
            unique_together=set([('zrodlo', 'rok')]),
        ),
        migrations.CreateModel(
            name='Zrodlo_Informacji',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('nazwa', models.CharField(unique=True, max_length=512)),
            ],
            options={
                'verbose_name': b'\xc5\xbar\xc3\xb3d\xc5\x82o informacji o bibliografii',
                'verbose_name_plural': b'\xc5\xbar\xc3\xb3d\xc5\x82a informacji o bibliografii',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='informacja_z',
            field=models.ForeignKey(on_delete=models.CASCADE, blank=True, to='bpp.Zrodlo_Informacji', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='informacja_z',
            field=models.ForeignKey(on_delete=models.CASCADE, blank=True, to='bpp.Zrodlo_Informacji', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='praca_habilitacyjna',
            name='informacja_z',
            field=models.ForeignKey(on_delete=models.CASCADE, blank=True, to='bpp.Zrodlo_Informacji', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='praca_doktorska',
            name='informacja_z',
            field=models.ForeignKey(on_delete=models.CASCADE, blank=True, to='bpp.Zrodlo_Informacji', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='patent',
            name='informacja_z',
            field=models.ForeignKey(on_delete=models.CASCADE, blank=True, to='bpp.Zrodlo_Informacji', null=True),
            preserve_default=True,
        ),

        RunSQL("CREATE OR REPLACE LANGUAGE plpython3u"),
        RunPython(lambda *args, **kw: load_custom_sql("0001_indeksy")),
        RunPython(lambda *args, **kw: load_custom_sql("0001_tytul_oryginalny_sort_triggers")),
        RunPython(lambda *args, **kw: load_custom_sql("0001_widoki_kronika")),
        RunPython(lambda *args, **kw: load_custom_sql("0001_widoki_sumy")),
        RunPython(lambda *args, **kw: load_custom_sql("0001_widoki_rekord")),
        RunPython(lambda *args, **kw: load_custom_sql("0001_widoki_autorzy")),
        RunPython(lambda *args, **kw: load_custom_sql("0001_fulltext")),

        RunPython(lambda *args, **kw: load_custom_sql("0001_cache_init")),
        RunPython(lambda *args, **kw: load_custom_sql("0001_cache_functions"))
    ]



# -*- encoding: utf-8 -*-
"""Importuje bazę danych BPP z istniejącego serwera PostgreSQL"""

import os
import sys
import lxml.html
import traceback
from collections import defaultdict
from pathlib import Path
from time import time

import psycopg2.extensions
from django.db import IntegrityError

from bpp.models.abstract import (
    ILOSC_ZNAKOW_NA_ARKUSZ,
    parse_informacje,
    wez_zakres_stron,
)
from bpp.models.cache import Rekord
from bpp.models.konferencja import Konferencja
from bpp.models.seria_wydawnicza import Seria_Wydawnicza
from bpp.models.struktura import Uczelnia
from bpp.templatetags.prace import close_tags
from bpp.util import get_fixture, set_seq

psycopg2.extensions.register_type(psycopg2.extensions.UNICODE)
psycopg2.extensions.register_type(psycopg2.extensions.UNICODEARRAY)

import decimal
import json
from datetime import datetime

from django.contrib.admin.models import LogEntry, ADDITION, CHANGE
from django.contrib.contenttypes.models import ContentType
from django.core.management.base import BaseCommand
from django.db import transaction, DatabaseError
from django.contrib.auth.models import Group
import psycopg2
from psycopg2 import extras

import bpp
from bpp.models.autor import Autor_Jednostka
from bpp.models.system import (
    Typ_KBN,
    Status_Korekty,
    Jezyk,
    Zrodlo_Informacji,
    Typ_Odpowiedzialnosci,
    Charakter_Formalny,
)
from bpp.models.wydawnictwo_ciagle import Wydawnictwo_Ciagle, Wydawnictwo_Ciagle_Autor
from bpp.models.wydawnictwo_zwarte import Wydawnictwo_Zwarte, Wydawnictwo_Zwarte_Autor
from bpp.models.profile import BppUser as User
from bpp.models import (
    Jednostka,
    Wydzial,
    Rodzaj_Zrodla,
    Zrodlo,
    Tytul,
    Autor,
    Praca_Doktorska,
    Praca_Habilitacyjna,
    Patent,
    Patent_Autor,
)

from django.db.models import Model
from django.conf import settings

settings.DEBUG = False


# Put this on your base model (or monkey patch it onto django's Model if that's your thing)
def reload(self):
    new_self = self.__class__.objects.get(pk=self.pk)
    # You may want to clear out the old dict first or perform a selective merge
    self.__dict__.update(new_self.__dict__)


Model.reload = reload

_user_cache = None


def find_user(login):
    if login is None or login == "":
        return None

    global _user_cache

    if _user_cache is None:
        _user_cache = dict([(x.pk, x) for x in User.objects.all()])

    return _user_cache[login]


def convert_www(s):
    if s is None:
        return

    if not s:
        return

    s = s.strip()

    if not s:
        return

    if s.lower().startswith("http://"):
        return s

    return "http://" + s


def punktacja(dct, kw):
    kw.update(
        dict(
            # ModelPunktowany
            impact_factor=dct["impact"] or 0.00,
            punkty_kbn=dct["pk"] or 0.00,
            index_copernicus=dct["ind_cop"] or 0.00,
            punktacja_wewnetrzna=dct["pkt_wewn"] or 0.00,
            weryfikacja_punktacji=dct["weryfikacja_punktacji"],
            kc_impact_factor=dct["kc_impact"],
            kc_punkty_kbn=dct["kc_pk"],
            kc_index_copernicus=dct["kc_ind_cop"],
        )
    )


def afiliacja(dct, kw):
    kw.update(
        dict(
            # ModelAfiliowanyRecenzowany
            recenzowana=dct["recenzowana"]
        )
    )

    for field in ["recenzowana"]:
        if kw[field] == None:
            # print "Ustawiam %s=False dla pracy z ID: %s " % (field, dct['id'])
            kw[field] = False


def szczegoly_i_inne(dct, kw, zrodlowe_pole_dla_informacji):
    d = dict(
        pk=dct["id"],
        # ModelZeSzczegolami
        # informacje=
        szczegoly=dct["szczegoly"],
        uwagi=dct["uwagi"],
        slowa_kluczowe=dct["slowa_kluczowe"],
        tom=dct["tom"],
        # ModelZRokiem
        rok=dct["rok_publikacji"],
        # ModelZWWW
        www=convert_www(dct["www_old"]),
    )

    if zrodlowe_pole_dla_informacji is not None:
        d["informacje"] = dct[zrodlowe_pole_dla_informacji] or ""
        d["informacje"] = d["informacje"].strip()

    if "informacje" in d:
        if d["informacje"]:
            if not d["tom"]:
                d["tom"] = parse_informacje(d["informacje"], "tom")

    if d["szczegoly"]:
        d["strony"] = wez_zakres_stron(d["szczegoly"])

    kw.update(d)


def idx(klass, attr="pk"):
    "Pobiera wszystkie modele klasy 'klass' do słownika wg. indeksu atrybuty 'attr'"
    return dict([(getattr(x, attr), x) for x in klass.objects.all()])


class Cache:
    def __init__(self):
        pass

    def initialize(self):
        self.typy_kbn = idx(Typ_KBN)
        self.jezyki = idx(Jezyk)
        self.statusy_korekty = idx(Status_Korekty)
        self.informacje_z = idx(Zrodlo_Informacji, "nazwa")
        self.typy_odpowiedzialnosci = idx(Typ_Odpowiedzialnosci)
        self.charaktery = idx(Charakter_Formalny, "skrot")
        self.jednostki = idx(Jednostka)
        self.zrodla = idx(Zrodlo)
        try:
            self.obca_jednostka = Jednostka.objects.get(nazwa="Obca Jednostka")
        except Jednostka.DoesNotExist:
            pass


cache = Cache()

NOWE_CHARAKTERY_MAPPING = {
    "AP": "AC",
    "API": "AC",
    "AZ": "AC",
    "PRI": "PRZ",
    "PSI": "PSZ",
    "S": None,
    "PW": None,
    "DOK": "D",
    "HAB": "H",
    "PODR": "PA",
    "PSUM": "PSZ",
    "ZSUM": None,
    "BPEX": None,
}


def nowy_charakter_formalny(skrot):
    """Przemapuj 'stary' charakter formalny na nowy charakter formalny,
    wg. zmian ustalonych w listopadzie 2014 r.
    """
    try:
        # !!!! WYŁĄCZONE !!!!
        # return cache.charaktery[NOWE_CHARAKTERY_MAPPING.get(skrot, skrot)]
        return cache.charaktery[skrot]
    except KeyError as e:
        print("KEY ERROR DLA SKROTU %r" % skrot)
        raise e


def jezyki_statusy(dct, kw):
    kw.update(
        dict(
            # ModelTypowany
            jezyk=cache.jezyki[dct["jezyk"]],
            typ_kbn=cache.typy_kbn.get(dct["kbn"], cache.typy_kbn[12]),
            # ModelZeStatusem
            status_korekty=cache.statusy_korekty[int(dct["status"])],
            # ModelZInformacjaZ
            informacja_z=cache.informacje_z.get(dct["info_src"], None),
        )
    )


def dwa_tytuly(dct, kw):
    kw.update(
        dict(
            # ModelZTytulem
            tytul_oryginalny=close_tags(dct["tytul_or"]),
            tytul=close_tags(dct["title"]),
        )
    )


def doi(dct, kw):
    kw.update(dict(doi=dct["doi"]))


def poprzestawiaj_wartosci_pol(kw, bib, zakazane, docelowe):
    for field in zakazane:
        if bib[field]:
            op = lambda x, y: (x + " " + y).strip()
            _docelowe = docelowe
            if field == "new_zrodlo":
                try:
                    # Dla habilitacji, tytuł źródła do pola "Informacje"
                    bib["new_zrodlo"] = cache.zrodla[bib["new_zrodlo"]].nazwa
                    _docelowe = "new_zrodlo_src"  # informacje"
                    op = lambda x, y: (y + " " + x).strip()
                except IndexError:
                    bib["new_zrodlo"] = (
                        "Zrodlo o id %s nie znalezione" % bib["new_zrodlo"]
                    )

            if hasattr(bib[field], "strip"):
                bib[field] = bib[field].strip()

            skrot = charakter.get(bib["charakter"])["skrot"].strip()

            msg = [
                "REKORD: \t",
                str(bib["id"]),
                "\tchar: ",
                str(bib["charakter"]),
                "\t",
                skrot,
                "\tZAWIERA WARTOSC DLA POLA \t",
                field,
                "PRZENOSZE DO POLA '",
                _docelowe,
                "' (wartosc: ",
                str(bib[field]),
                ")",
            ]

            print("%r" % " ".join(msg))

            if kw.get("legacy_data") is None:
                kw["legacy_data"] = {}

            kw["legacy_data"] = {field: bib[field]}

            if bib[_docelowe] is None:
                bib[_docelowe] = ""

            if type(bib[field]) == int:
                bib[field] = str(bib[field])

            bib[_docelowe] = op(bib[_docelowe], bib[field])
            bib[field] = ""


def skoryguj_wartosci_pol(bib):
    if bib["new_zrodlo"] == 0:
        bib["new_zrodlo"] = -1


_wez_autorow_cache = None


def wez_autorow(pk, pgsql_conn):
    global _wez_autorow_cache

    if _wez_autorow_cache is None:
        _wez_autorow_cache = defaultdict(lambda: [])

        print("Cache fetch")
        cur2 = pgsql_conn.cursor(cursor_factory=extras.DictCursor)
        cur2.execute(
            """
            SELECT 
              idt,
              id, 
              idt_aut, 
              idt_jed, 
              lp, 
              naz_zapis, 
              typ_autora,
              afiliuje,
              zatrudniony
            FROM 
              b_a
              """
        )
        #    """)
        # WHERE
        #   idt = %s
        #   """ % pk)
        while True:
            elem = cur2.fetchone()
            if elem is None:
                break
            _wez_autorow_cache[elem["idt"]].append(elem)
        cur2.close()
        print("Fetch done")

    return _wez_autorow_cache[pk]


def zrob_autorow_dla(wc, klass, pgsql_conn):
    for row in wez_autorow(wc.pk, pgsql_conn):
        if row["idt_jed"] == 0:
            row["idt_jed"] = -1

        # autor = Autor.objects.get(pk=row['idt_aut'])

        if row["typ_autora"] == 0 or row["typ_autora"] is None:
            print("REKORD", row["id"], "TYP AUTORA == 0 lub None USTAWIAM NA 1")
            row["typ_autora"] = 1

        typ = cache.typy_odpowiedzialnosci[row["typ_autora"]]
        jednostka = cache.jednostki[row["idt_jed"]]
        zatrudniony = row["zatrudniony"] or False
        afiliuje = row["afiliuje"] or False

        try:
            klass.objects.create(
                rekord=wc,
                autor_id=row["idt_aut"],
                jednostka=jednostka,
                kolejnosc=row["lp"],
                zapisany_jako=row["naz_zapis"],
                typ_odpowiedzialnosci=typ,
                afiliuje=afiliuje,
                zatrudniony=zatrudniony,
            )
        except IntegrityError as e:
            print("ERROR dla pracy %r, row=%r" % (wc, row))
            raise e


def zrob_wydzialy(cur):
    cur.execute(
        """
    SELECT id, skrot, nazwa, opis, skr_nazwy, id_polon, sort
    FROM wyd"""
    )

    while True:
        l = cur.fetchone()
        if l is None:
            break
        Wydzial.objects.create(
            pk=l["id"],
            uczelnia_id=Uczelnia.objects.all().first().pk,
            nazwa=l["nazwa"],
            skrot=l["skrot"],
            skrot_nazwy=l["skr_nazwy"],
            poprzednie_nazwy=l["opis"],
            pbn_id=l["id_polon"],
            kolejnosc=l["sort"],
        )


def zrob_userow(cur):
    cur.execute(
        """SELECT login, haslo, nazwisko_i_imie, e_mail, 
      COALESCE(adnotacje, '') as adnotacje,
            uprawnienia, id, created_on, last_access, created_by, edited_by
            FROM users ORDER BY id"""
    )
    later = []
    while True:
        l = cur.fetchone()
        if l is None:
            break

        print(l["nazwisko_i_imie"])
        try:
            imie, nazwisko = l["nazwisko_i_imie"].split(" ", 1)
        except ValueError:
            nazwisko = l["nazwisko_i_imie"]
            imie = ""

        uprawnienia = l["uprawnienia"].split(":")

        u = User.objects.create(
            pk=l["id"],
            username=l["login"],
            is_staff=True,
            first_name=imie,
            last_name=nazwisko,
            email=l["e_mail"] or "brak@email.pl",
        )
        u.set_password(l["haslo"])
        u.save()

        for letter, name in list(
            dict(
                S="dane systemowe",
                E="wprowadzanie danych",
                B="przeglądanie",
                I="indeks autorów",
                A="administracja",
            ).items()
        ):
            if letter in uprawnienia:
                if letter == "B":
                    # Ignorujemy grupę "przeglądanie" totalnie
                    continue
                u.groups.add(Group.objects.get(name=name))
                # dołóż wszystkim którzy mogą wprowadzać
                # dane opcje edycji struktury uczelni:
                if letter == "E":
                    u.groups.add(Group.objects.get(name="struktura"))
                # administratorzy i mogący edytować dane systemowe dostają
                # grupę "web"
                if letter in ["S", "A"]:
                    u.groups.add(Group.objects.get(name="web"))
                    u.groups.add(Group.objects.get(name="raporty"))

        u.utworzony = l["created_on"]
        if l["created_by"] is not None:
            try:
                u.utworzony_przez = User.objects.get(pk=l["created_by"])
            except User.DoesNotExist:
                later.append((u.pk, "utworzony_przez", l["created_by"]))
                pass

        u.zmieniony = l["last_access"]
        if l["edited_by"] is not None:
            try:
                u.zmieniony_przez = User.objects.get(pk=l["edited_by"])
            except User.DoesNotExist:
                later.append((u.pk, "zmieniony_przez", l["edited_by"]))

        u.adnotacje = l["adnotacje"] or ""
        u.save()

    for pk, attribute, value in later:
        u = User.objects.get(pk=pk)
        setattr(u, attribute, User.objects.get(pk=value))
        u.save()


def utworzono(model, bib):
    model.utworzono = bib["created_on"]
    model.save()


def admin_log_history(obj, dct):
    user = find_user(dct["created_by"])
    if user is not None:
        # obj.reload()
        kw = dict(
            user_id=user.pk,
            content_type_id=ContentType.objects.get_for_model(obj).pk,
            object_id=obj.pk,
            object_repr=str(obj),
            change_message="Import z poprzedniej wersji bazy danych",
            action_flag=ADDITION,
        )
        try:
            LogEntry.objects.log_action(**kw)
        except DatabaseError as e:
            print(e)
            print(kw)
            raise e

    user = find_user(dct["edited_by"])
    if user is not None:
        # obj.reload()
        LogEntry.objects.log_action(
            user_id=user.pk,
            content_type_id=ContentType.objects.get_for_model(obj).pk,
            object_id=obj.pk,
            object_repr=str(obj),
            change_message="Ostatnia edycja w poprzedniej wersji bazy danych",
            action_flag=CHANGE,
        )
    utworzono(obj, dct)


def zrob_jednostki(cur, initial_offset, skip):
    cur.execute(
        """SELECT id, skrot, nazwa, wyd, to_print, email, www,
            created_on, last_access, created_by, edited_by, opis
            FROM jed OFFSET %s"""
        % initial_offset
    )

    while True:
        jed = cur.fetchone()
        if jed is None:
            break

        wyd = Wydzial.objects.get(pk=jed["wyd"])

        # Jest to konieczne, bo coś potem autocomplete się psuje... i podobnie
        # dla innych ID w bazie
        if jed["id"] == 0:
            jed["id"] = -1

        kw = dict(
            pk=jed["id"],
            nazwa=jed["nazwa"],
            skrot=jed["skrot"],
            wydzial=wyd,
            widoczna=jed["to_print"] == "*",
            email=jed["email"],
            www=convert_www(jed["www"]),
            adnotacje=jed["opis"] or "",
        )
        j = Jednostka.objects.create(**kw)
        admin_log_history(j, jed)

        for _skip in range(skip):
            cur.fetchone()


def zrob_zrodla(cur, initial_offset, skip):
    cur.execute(
        """SELECT 
              rodzaj, 
              skrot, 
              www, 
              nazwa, 
              adnotacje,
              id, 
              created_on, last_access, created_by, edited_by, 
              issn, 
              e_issn, 
              issn2, 
              doi,
              wydawca,
              wlasciwy
            FROM zrodla OFFSET %s"""
        % initial_offset
    )

    while True:
        zrod = cur.fetchone()
        if zrod is None:
            break

        if zrod["id"] == 0:
            # źródło nieindeksowane
            continue

        try:
            rodzaj = Rodzaj_Zrodla.objects.get(pk=zrod["rodzaj"])
        except Rodzaj_Zrodla.DoesNotExist as e:
            print("Brak rodzaju zrodla: %s" % zrod["rodzaj"])
            raise e

        issn = (zrod["issn"] or "").strip()
        issn2 = (zrod["issn2"] or "").strip()
        issn = issn or issn2

        kw = dict(
            pk=zrod["id"],
            rodzaj=rodzaj,
            skrot=zrod["skrot"],
            www=zrod["www"],
            nazwa=zrod["nazwa"],
            adnotacje=zrod["adnotacje"] or "",
            issn=issn,
            e_issn=zrod["e_issn"],
            doi=zrod["doi"],
            wydawca=zrod["wydawca"] or "",
            nazwa_alternatywna=zrod["wlasciwy"],
        )

        z = Zrodlo.objects.create(**kw)
        admin_log_history(z, zrod)

        for _skip in range(skip):
            cur.fetchone()


@transaction.atomic
def zrob_autorow(cur, initial_offset=0, skip=0):
    tytuly = dict([(x.skrot, x) for x in Tytul.objects.all()])

    cur.execute(
        """SELECT id, imiona, nazwisko, idt_jed, email, www, tytul,
            stanowisko, urodzony, zmarl, created_on, created_by, last_access,
            edited_by, adnotacje, haslo, hide_on_unit, dawne_nazwisko
            FROM aut ORDER BY nazwisko, imiona OFFSET %s"""
        % initial_offset
    )

    while True:
        aut = cur.fetchone()
        if aut is None:
            break

        aut["tytul"] = (aut["tytul"] or "").strip()

        tytul = None
        if aut["tytul"]:
            try:
                tytul = tytuly[aut["tytul"]]
            except KeyError:
                tytul = Tytul.objects.create(nazwa=aut["tytul"], skrot=aut["tytul"])
                print("UTWORZYLEM TYTUL", tytul)

        imiona = aut["imiona"]
        if imiona is None:
            imiona = ""

        kw = dict(
            pk=aut["id"],
            imiona=imiona,
            nazwisko=aut["nazwisko"].strip(),
            tytul=tytul,
            email=aut["email"],
            adnotacje=aut["adnotacje"] or "",
            www=convert_www(aut["www"]),
            urodzony=aut["urodzony"],
            zmarl=aut["zmarl"],
            pokazuj=int(aut["hide_on_unit"]) == 0,
            poprzednie_nazwiska=aut["dawne_nazwisko"],
        )

        a = Autor.objects.create(**kw)
        admin_log_history(a, aut)

        for _skip in range(skip):
            cur.fetchone()


def zrob_powiazania(cur, initial_offset, skip):
    # W "starym" systemie istnieje powiązanie autora do jednostki na obiekcie
    # autora. W "nowym" jest wiele miejsc pracy i tak dalej. ALE potrzebujemy
    # aktualnego przypisania autora do jednostki. ZATEM: bierzemy to przypisanie
    # ze "starego" i w dniu importu danych nadajemy mu pozory aktualności,
    # nadając datę POCZATEK PRACY W DANYM MIEJSCU dla tego miejsca.

    # Powiązania autor-jednostka
    cur.execute(
        """SELECT DISTINCT
                b_a.idt_aut,
                b_a.idt_jed,
                aut.idt_jed AS current_idt_jed
            FROM
                b_a,
                aut
            WHERE
                aut.id = idt_aut
                AND b_a.zatrudniony = 't'
            OFFSET %s"""
        % initial_offset
    )

    while True:
        b_a = cur.fetchone()
        if b_a is None:
            break

        if b_a["idt_jed"] == 0:
            b_a["idt_jed"] = -1

        try:
            jednostka = Jednostka.objects.get(pk=b_a["idt_jed"])
        except:
            raise Exception("BRAK JEDNOSTKI O ID: ", b_a["idt_jed"])

        try:
            autor = Autor.objects.get(pk=b_a["idt_aut"])
        except:
            raise Exception("BRAK AUTORA O ID: ", b_a["idt_aut"])

        rozpoczal_prace = None
        if b_a["current_idt_jed"] == b_a["idt_jed"]:
            rozpoczal_prace = datetime.now().date()

        Autor_Jednostka.objects.create(
            autor=autor,
            jednostka=jednostka,
            rozpoczal_prace=rozpoczal_prace,
            zakonczyl_prace=None,
            funkcja=None,
        )

        for _skip in range(skip):
            cur.fetchone()


def openaccess(bib, kw):
    kw.update(
        dict(
            openaccess_czas_publikacji_id=bib["oa_data"],
            openaccess_licencja_id=bib["oa_licencja"],
            openaccess_tryb_dostepu_id=bib["oa_sposob"],
            openaccess_wersja_tekstu_id=bib["oa_wersja"],
            public_www=bib["oa_link"],
        )
    )


def zrob_import_z_tabeli(kw, bib, zakazane, docelowe, zrodlowe_pole_dla_informacji):
    # Tych pól wydawnictwo ma nie mieć
    poprzestawiaj_wartosci_pol(kw, bib, zakazane, docelowe)
    skoryguj_wartosci_pol(bib)

    punktacja(bib, kw)
    afiliacja(bib, kw)
    dwa_tytuly(bib, kw)
    szczegoly_i_inne(bib, kw, zrodlowe_pole_dla_informacji)
    jezyki_statusy(bib, kw)

    for pole in ["nrbibl", "typ_polon", "cechy_polon", "afiliowana"]:
        if bib[pole]:
            if "legacy_data" not in kw:
                kw["legacy_data"] = {}

            kw["legacy_data"][pole] = bib[pole]

    kw["pbn_id"] = bib["id"]


def zrob_wydawnictwo(
    kw,
    bib,
    klass,
    autor_klass,
    zakazane,
    docelowe,
    pgsql_conn,
    zrodlowe_pole_dla_informacji,
    usun_przed=None,
):
    zrob_import_z_tabeli(kw, bib, zakazane, docelowe, zrodlowe_pole_dla_informacji)
    if usun_przed:
        for field in usun_przed:
            del kw[field]

    if bib["konf_nazwa"]:
        kw["konferencja"] = Konferencja.objects.get(nazwa=bib["konf_nazwa"].strip())

    try:
        wc = klass.objects.create(**kw)
    except decimal.InvalidOperation as e:
        print(kw)
        raise e
    admin_log_history(wc, bib)
    zrob_autorow_dla(wc, autor_klass, pgsql_conn)
    return wc


@transaction.atomic
def zrob_wydawnictwo_ciagle(bib, skrot, pgsql_conn):
    kw = dict(
        # Wydawnictwo_Ciagle
        zrodlo_id=bib["new_zrodlo"],
        charakter_formalny=nowy_charakter_formalny(skrot),
        nr_zeszytu=bib["nr_zeszytu"],
    )

    bib["nr_zeszytu"] = None

    doi(bib, kw)
    openaccess(bib, kw)

    w = zrob_wydawnictwo(
        kw,
        bib,
        Wydawnictwo_Ciagle,
        Wydawnictwo_Ciagle_Autor,
        zakazane=["redakcja", "mceirok", "wydawnictwo", "isbn", "nr_zeszytu"],
        docelowe="uwagi",
        pgsql_conn=pgsql_conn,
        zrodlowe_pole_dla_informacji="new_zrodlo_src",
    )

    if not w.nr_zeszytu and w.informacje:
        _old = w.nr_zeszytu
        w.nr_zeszytu = parse_informacje(w.informacje, "numer")
        if w.nr_zeszytu != _old:
            w.save()

    zrob_znaki_wydawnicze(bib, w)

    # admin_log_history(w, bib)


def zrob_baze_wydawnictwa_zwartego(bib):
    kw = dict(
        miejsce_i_rok=bib["mceirok"],
        wydawnictwo=bib["wydawnictwo"],
        redakcja=bib["redakcja"],
        isbn=bib["isbn"],
        informacje=bib["new_zrodlo_src"],
    )

    return kw


def zrob_znaki_wydawnicze(bib, wc):
    modified = False
    if bib["ilosc_znakow_wydawnicznych"] is not None:
        wc.liczba_znakow_wydawniczych = bib["ilosc_znakow_wydawnicznych"]
        modified = True

    if bib["ilosc_arkuszy_wydawniczych"] is not None:
        wc.liczba_znakow_wydawniczych = (
            bib["ilosc_arkuszy_wydawniczych"] * ILOSC_ZNAKOW_NA_ARKUSZ
        )
        modified = True

    if modified:
        wc.save()


@transaction.atomic
def zrob_wydawnictwo_zwarte(bib, skrot, pgsql_conn):
    kw = zrob_baze_wydawnictwa_zwartego(bib)
    kw["charakter_formalny"] = nowy_charakter_formalny(skrot)
    bib["new_zrodlo_src"] = None
    doi(bib, kw)
    openaccess(bib, kw)

    wc = zrob_wydawnictwo(
        kw,
        bib,
        Wydawnictwo_Zwarte,
        Wydawnictwo_Zwarte_Autor,
        zakazane=["new_zrodlo", "new_zrodlo_src", "nr_zeszytu"],
        docelowe="uwagi",
        pgsql_conn=pgsql_conn,
        zrodlowe_pole_dla_informacji=None,
    )

    if bib["seria"]:
        wc.seria_wydawnicza = Seria_Wydawnicza.objects.get(nazwa=bib["seria"])

    zrob_znaki_wydawnicze(bib, wc)


@transaction.atomic
def zrob_doktorat_lub_habilitacje(bib, pgsql_conn):
    kw = zrob_baze_wydawnictwa_zwartego(bib)

    zrob_import_z_tabeli(
        kw,
        bib,
        zakazane=["new_zrodlo", "nr_zeszytu"],
        docelowe="uwagi",
        zrodlowe_pole_dla_informacji="new_zrodlo_src",
    )

    autor = wez_autorow(bib["id"], pgsql_conn)
    if len(autor) != 1:
        print(
            (
                "dla pracy doktorskiej/habilitacyjnej z id %s ilosc autorow jest rowna %s, IGNORUJE TEN WPIS"
                % (bib["id"], len(autor))
            )
        )
        return

    kw["autor"] = Autor.objects.get(pk=autor[0]["idt_aut"])
    kw["jednostka"] = Jednostka.objects.get(pk=autor[0]["idt_jed"])

    # 20140714 brak doktoratów w UP
    # if bib['charakter'] == 21:  # praca doktorska
    #    klass = Praca_Doktorska
    # el
    if bib["charakter"] == 5:  # praca habilitacyjna
        klass = Praca_Habilitacyjna
    else:
        raise Exception(
            "Probuje zaimportowac doktorat lub habilitacje, a charakter to %s"
            % bib["charakter"]
        )

    try:
        r = klass.objects.create(**kw)
    except decimal.InvalidOperation as e:
        print(kw)
        raise e

    admin_log_history(r, bib)


def zrob_jezyki(cursor):
    Jezyk.objects.all().delete()
    cursor.execute("SELECT id, trim(skrot) as skrot, nazwa FROM jez")
    for elem in cursor.fetchall():
        kw = {}
        if elem["skrot"] == "POL":
            elem["skrot"] = "pol."
            kw["skrot_dla_pbn"] = "PL"
        if elem["skrot"] == "ENG":
            kw["skrot_dla_pbn"] = "EN"
        Jezyk.objects.create(
            pk=elem["id"],
            nazwa=elem["nazwa"].strip(),
            skrot=elem["skrot"].strip(),
            **kw
        )
    set_seq("bpp_jezyk")


def zrob_kbn(cursor):
    artykuly_pbn = ["cr", "pak", "mon", "po", "pp", "pnp", "rc"]
    Typ_KBN.objects.all().delete()
    cursor.execute("SELECT id, skrot, nazwa FROM kbn")
    for elem in cursor.fetchall():
        skrot = elem["skrot"].strip()
        if skrot == "MON":
            skrot = "mon"
        Typ_KBN.objects.create(
            pk=elem["id"],
            nazwa=elem["nazwa"].strip(),
            skrot=skrot,
            artykul_pbn=elem["skrot"].strip().lower() in artykuly_pbn,
        )
    set_seq("bpp_typ_kbn")


def zrob_typy_odpowiedzialnosci(cursor):
    Typ_Odpowiedzialnosci.objects.all().delete()
    cursor.execute("SELECT id, skrot2, nazwa FROM typy_autorow")
    for elem in cursor.fetchall():
        Typ_Odpowiedzialnosci.objects.create(
            pk=elem["id"],
            nazwa=elem["nazwa"],
            skrot=elem["skrot2"].replace("[", "").replace("]", "").lower(),
        )


def zrob_charaktery_formalne(cursor):
    Charakter_Formalny.objects.all().delete()
    cursor.execute("SELECT id, skrot, nazwa FROM pub")

    f = get_fixture("charakter_formalny")
    artykul_pbn = ["ac", "supl", "l", "ap", "az", "api"]
    ksiazka_pbn = ["ks", "ksz", "ksp", "skr", "pa"]
    rozdzial_pbn = ["frg", "roz", "rozs", "pa", "rozp"]

    for elem in cursor.fetchall():
        kw = {"nazwa": elem["nazwa"]}

        skrot_l = elem["skrot"].lower().strip()
        extra = f.get(skrot_l)
        if extra:
            del extra["skrot"]
            kw.update(extra)
        else:
            print(
                "Dla charakteru formalnego %s nie ma ekstra-informacji"
                % (elem["skrot"] + elem["nazwa"])
            )

        Charakter_Formalny.objects.create(
            pk=elem["id"],
            skrot=elem["skrot"].strip(),
            artykul_pbn=skrot_l in artykul_pbn,
            ksiazka_pbn=skrot_l in ksiazka_pbn,
            rozdzial_pbn=skrot_l in rozdzial_pbn,
            **kw
        )
    set_seq("bpp_charakter_formalny")
    Charakter_Formalny.objects.create(
        skrot="ROZS",
        nazwa="Rozdział skryptu",
        nazwa_w_primo="Rozdział",
        rozdzial_pbn=True,
    )


@transaction.atomic
def zrob_indeksy(cursor):
    zrob_jezyki(cursor=cursor)
    zrob_kbn(cursor)
    zrob_charaktery_formalne(cursor)
    zrob_typy_odpowiedzialnosci(cursor)


# @transaction.atomic
def zrob_patent(bib, pgsql_conn):
    kw = zrob_baze_wydawnictwa_zwartego(bib)
    p = zrob_wydawnictwo(
        kw,
        bib,
        Patent,
        Patent_Autor,
        zakazane=["new_zrodlo", "new_zrodlo_src", "konf_nazwa"],
        docelowe="uwagi",
        pgsql_conn=pgsql_conn,
        zrodlowe_pole_dla_informacji=None,
        usun_przed=[
            "tytul",
            "isbn",
            "wydawnictwo",
            "redakcja",
            "typ_kbn",
            "jezyk",
            "miejsce_i_rok",
        ],
    )

    # admin_log_history(p, bib)


charakter = {}


def zrob_publikacje(cur, pgsql_conn, initial_offset, skip):
    global charakter

    cur.execute("SELECT * FROM pub")
    charakter = dict([(x["id"], x) for x in cur.fetchall()])

    cur.execute(
        """SELECT 
          id, 
          tytul_or, 
          title, 
          zrodlo, 
          szczegoly, 
          uwagi,
          charakter, 
          impact, 
          redakcja, 
          status, 
          rok, 
          rok_publikacji, 
          edited_by,
          kbn, 
          afiliowana, 
          recenzowana, 
          jezyk, 
          pk, 
          created_on, 
          last_access,
          created_by, 
          edited_by, 
          new_zrodlo, 
          new_zrodlo_src, 
          mceirok,
          wydawnictwo, 
          slowa_kluczowe, 
          www_old, 
          ind_cop, 
          pkt_wewn,
          auto_pk, 
          isbn, 
          nr_zeszytu, 
          NULL AS info_src, 
          impact AS kc_impact, 
          pk AS kc_pk, 
          ind_cop AS kc_ind_cop,
          false AS weryfikacja_punktacji, 
          NULL AS ilosc_znakow_wydawnicznych,
          arkusze AS ilosc_arkuszy_wydawniczych,
          
          doi,
          
          oa_sposob,
          oa_licencja,
          oa_wersja, 
          oa_data,
          oa_link,
          
          tom,
          
          nrbibl,
          seria,
          
          typ_polon,
          cechy_polon,
          
          konf_nazwa
          
      FROM 
        bib 
        
      WHERE
        charakter IS NOT NULL
        
      ORDER BY id OFFSET %s"""
        % initial_offset
    )

    # Charakter 5 => praca habilitacyjna
    # Charakter 16 => patent

    # start_time = None
    cnt = 0
    while True:
        # if start_time is None:
        #     start_time = time()
        bib = cur.fetchone()
        if bib is None:
            break

        try:
            skrot = charakter.get(bib["charakter"])["skrot"].strip()
            if skrot == "T\xc5\x81":
                skrot = "TŁ"

            # if skrot == 'D' or skrot == 'H':
            #     # doktorat lub habilitacja
            #     zrob_doktorat_lub_habilitacje(bib, pgsql_conn)

            if skrot == "PAT":
                zrob_patent(bib, pgsql_conn)

            else:
                if bib["new_zrodlo"] and skrot not in ["D", "H"]:
                    zrob_wydawnictwo_ciagle(bib, skrot, pgsql_conn)
                else:
                    zrob_wydawnictwo_zwarte(bib, skrot, pgsql_conn)

        except:
            print("*** BLAD REKORD: %i" % bib["id"])
            traceback.print_exc(file=sys.stdout)

        # cnt += 1
        # if cnt % 100 == 0:
        #     print("%.2f recs/sec" % (cnt/(time()-start_time)))
        for _skip in range(skip):
            cur.fetchone()


class ColumnNotIndexed(Exception):
    def __init__(self, table, col, *args, **kw):
        super(ColumnNotIndexed, self).__init__(*args, **kw)
        self.table = table
        self.col = col

    def __str__(self):
        return (
            "No index. Create one with CREATE INDEX %(table)s_%(col)s_idx ON %(table)s(%(col)s)"
            % dict(table=self.table, col=self.col)
        )


def make_clusters():
    """Za pomocą CLUSTER układa tabele wg najczęściej stosowanych
    (czyli defaultowych) indeksów.
    """

    from django.db import connection

    django_cur = connection.cursor()

    def idx_name(table, col):
        django_cur.execute("SELECT pg_find_index('%s', '%s')" % (table, col))
        try:
            return django_cur.fetchall()[0][0]
        except IndexError:
            raise ColumnNotIndexed(table, col)

    def cluster(table, by):
        idx = idx_name(table, by)
        django_cur.execute("CLUSTER %s USING %s" % (table, idx))

    cluster("bpp_autor", "nazwisko")
    cluster("bpp_zrodlo", "nazwa")
    cluster("bpp_jednostka", "nazwa")
    for table in [
        "bpp_wydawnictwo_ciagle",
        "bpp_patent",
        "bpp_wydawnictwo_zwarte",
        "bpp_praca_doktorska",
        "bpp_praca_habilitacyjna",
    ]:
        cluster(table, "tytul_oryginalny")
    cluster("bpp_rekord_mat", "rok")


def zrob_rodzaje_zrodel(cur):
    Rodzaj_Zrodla.objects.all().delete()
    cur.execute("SELECT id, nazwa FROM zrodla_rodzaje")
    for elem in cur.fetchall():
        Rodzaj_Zrodla.objects.create(pk=elem["id"], nazwa=elem["nazwa"])


def zrob_konferencje(cur):
    Konferencja.objects.all().delete()
    cur.execute(
        """
        SELECT DISTINCT 
          konf_nazwa, 
          konf_nazwa2, 
          konf_od, 
          konf_do, 
          konf_miasto, 
          konf_panstwo, 
          bazy_scopus, 
          bazy_wos, 
          bazy_inna
        FROM bib
        WHERE COALESCE(konf_nazwa, '')!=''
        ORDER BY konf_nazwa, konf_od DESC
                """
    )
    for elem in cur.fetchall():
        Konferencja.objects.get_or_create(
            nazwa=elem["konf_nazwa"].strip(),
            defaults=dict(
                rozpoczecie=elem["konf_od"],
                skrocona_nazwa=elem["konf_nazwa2"],
                zakonczenie=elem["konf_do"],
                miasto=elem["konf_miasto"],
                panstwo=elem["konf_panstwo"],
                baza_scopus=elem["bazy_scopus"] or False,
                baza_wos=elem["bazy_wos"] or False,
                baza_inna=elem["bazy_inna"],
            ),
        )


def db_connect():
    pgsql_conn = psycopg2.connect(
        database=os.getenv("BPP_DB_REBUILD_SOURCE_DB_NAME", "prace-ar"),
        user=os.getenv("BPP_DB_REBUILD_SOURCE_DB_USER", "bpp"),
        password=os.getenv("BPP_DB_REBUILD_SOURCE_DB_PASSWORD", ""),
        host=os.getenv("BPP_DB_REBUILD_SOURCE_DB_HOST", "localhost"),
        port=int(os.getenv("BPP_DB_REBUILD_SOURCE_DB_PORT", "5432")),
    )
    pgsql_conn.set_client_encoding("UTF8")
    return pgsql_conn


def db_disconnect(cur):
    cur.close()


class Command(BaseCommand):
    help = "Importuje baze danych BPP z istniejacego serwera PostgreSQL"

    def add_arguments(self, parser):
        parser.add_argument("--uzytkownicy", action="store_true")

        parser.add_argument("--uczelnia", action="store_true")
        parser.add_argument("--nazwa-uczelni", action="store", type=str)
        parser.add_argument("--nazwa-uczelni-skrot", action="store", type=str)
        parser.add_argument("--nazwa-uczelni-w-dopelniaczu", action="store", type=str)

        parser.add_argument("--wydzialy", action="store_true")
        parser.add_argument("--jednostki", action="store_true")
        parser.add_argument("--zrodla", action="store_true")
        parser.add_argument("--autorzy", action="store_true")
        parser.add_argument("--powiazania", action="store_true")
        parser.add_argument("--indeksy", action="store_true")
        parser.add_argument("--konferencje", action="store_true")

        parser.add_argument("--korekty", action="store_true")
        parser.add_argument("--serie", action="store_true")
        parser.add_argument("--publikacje", action="store_true")
        parser.add_argument("--clusters", action="store_true")
        parser.add_argument("--initial-offset", action="store", type=int, default=0)
        parser.add_argument("--skip", action="store", type=int, default=0)

    def handle(self, *args, **options):
        """
        Podajemy temu poleceniu
        argumenty np. --uzytkownicy, --jednostki, --autorzy, --zrodla,
        --korekty, --publikacje, --sekwencje, do tego podajemy parametr
        --skip=N (co ile rekordów przeskakiwać) oraz --initial-offset=M
        (ile rekordów przeskoczyć inicjalnie) i to polecenie zacznie
        importować konkretne rekordy do bazy danych, przeskakując co
        N-ty rekord.
        """

        print("Initial cache fill")
        cache.initialize()
        print("Cache fill done")
        pgsql_conn = db_connect()
        cur = pgsql_conn.cursor(cursor_factory=extras.DictCursor)

        if options["uzytkownicy"]:
            zrob_userow(cur)  # , options['initial_offset'], options['skip'])
            set_seq("bpp_bppuser")

        if options["uczelnia"]:
            Uczelnia.objects.create(
                nazwa=options["nazwa_uczelni"],
                nazwa_dopelniacz_field=options["nazwa_uczelni_w_dopelniaczu"],
                skrot=options["nazwa_uczelni_skrot"],
            )
            set_seq("bpp_uczelnia")

        if options["wydzialy"]:
            zrob_wydzialy(cur)  # , options['initial_offset'], options['skip'])
            set_seq("bpp_wydzial")

        if options["jednostki"]:
            print("JEDNOSTKI", options["initial_offset"])
            zrob_jednostki(cur, options["initial_offset"], options["skip"])
            set_seq("bpp_jednostka")

        if options["autorzy"]:
            zrob_autorow(cur, options["initial_offset"], options["skip"])
            set_seq("bpp_autor")

        if options["powiazania"]:
            zrob_powiazania(cur, options["initial_offset"], options["skip"])

        if options["indeksy"]:
            zrob_indeksy(cur)

        if options["konferencje"]:
            zrob_konferencje(cur)

        if options["serie"]:
            cur.execute("SELECT DISTINCT seria FROM bib WHERE seria IS NOT NULL")
            for elem in cur.fetchall():
                Seria_Wydawnicza.objects.create(nazwa=elem["seria"])

        if options["zrodla"]:
            zrob_rodzaje_zrodel(cur)
            set_seq("bpp_rodzaj_zrodla")

            zrob_zrodla(cur, options["initial_offset"], options["skip"])
            set_seq("bpp_zrodlo")

        # Publikacje
        if options["publikacje"]:
            from bpp.models.cache import disable as cache_disable

            cache_disable()

            try:
                zrob_publikacje(
                    cur, pgsql_conn, options["initial_offset"], options["skip"]
                )
            finally:
                set_seq("bpp_wydawnictwo_ciagle")
                set_seq("bpp_wydawnictwo_zwarte")
                set_seq("bpp_patent")
                set_seq("bpp_praca_doktorska")
                set_seq("bpp_praca_habilitacyjna")

        if options["korekty"]:
            # Uzupełnij charaktery formalne i typy KBN o to, czego
            # tam jeszcze nie ma:

            for obj, fixture in [
                (Charakter_Formalny, "um_lublin_charakter_formalny"),
                (Typ_KBN, "um_lublin_typ_kbn"),
            ]:
                f = get_fixture(fixture)
                for elem in f.values():
                    if obj == Charakter_Formalny:
                        elem["charakter_pbn_id"] = elem["charakter_pbn"]
                        del elem["charakter_pbn"]

                    try:
                        c = obj.objects.get(skrot=elem["skrot"])
                    except obj.DoesNotExist:
                        obj.objects.create(**elem)
                        continue

                    for key, value in elem.items():
                        setattr(c, key, value)

                    c.save()

            for klass in Wydawnictwo_Zwarte, Wydawnictwo_Ciagle:
                for stary, nowy in NOWE_CHARAKTERY_MAPPING.items():

                    try:
                        stary = Charakter_Formalny.objects.get(skrot=stary)
                    except Charakter_Formalny.DoesNotExist:
                        continue

                    if nowy is not None:
                        nowy = Charakter_Formalny.objects.get(skrot=nowy)

                    stare = klass.objects.filter(charakter_formalny=stary).order_by(
                        "pk"
                    )

                    for obj in stare:
                        if nowy is None:
                            print("*** KASUJE", obj.pk, obj)
                            obj.delete()
                            continue

                        print(stary.skrot, nowy.skrot, obj.pk, obj)

                        if obj.legacy_data is None:
                            obj.legacy_data = {}
                        obj.legacy_data["charakter_formalny__skrot"] = stary.skrot
                        obj.charakter_formalny = nowy
                        obj.save()

            for skrot in [
                "AP",
                "AZ",
                "API",
                "PRI",
                "BPEX",
                "KOM",
                "CZ",
                "SKR",
                "PZ",
                "BR",
                "WYN",
            ]:
                c = Charakter_Formalny.objects.get(skrot=skrot)
                if Rekord.objects.filter(charakter_formalny=c).count():
                    print("*** NIE KASUJE %s, ma rekordy" % skrot)
                else:
                    c.delete()

        if options["clusters"]:
            make_clusters()

        for nazwa in ["Obca jednostka", "Studenci Uniwersytetu Medycznego w Lublinie"]:
            try:
                x = Jednostka.objects.get(nazwa=nazwa)
            except Jednostka.DoesNotExist:
                pass
            else:
                x.wchodzi_do_raportow = False
                x.save()

        for nazwa in [
            "Jednostki Dawne",
            "Bez Wydziału",
            "Poza Wydziałem",
            "Brak wpisanego wydziału",
            "Wydział Lekarski",
            "Jednostka międzywydziałowa",
        ]:
            try:
                x = Wydzial.objects.get(nazwa=nazwa)
            except Wydzial.DoesNotExist:
                pass
            else:
                x.zezwalaj_na_ranking_autorow = False
                x.save()

        db_disconnect(cur)



# -*- coding: utf-8 -*-


from django.db import models, migrations
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0001_initial'),
        ('bpp', '0014_auto_20150530_1942'),
    ]

    operations = [
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='zrodlo',
            field=models.ForeignKey(on_delete=django.db.models.deletion.SET_NULL, verbose_name=b'\xc5\xb9r\xc3\xb3d\xc5\x82o', to='bpp.Zrodlo', null=True),
            preserve_default=True,
        ),
    ]



import urllib

import django_tables2 as tables
from django.template.defaultfilters import safe
from django.urls import reverse
from django_tables2 import Column

from raport_slotow import const
from raport_slotow.columns import DecimalColumn, SummingColumn
from raport_slotow.models import (
    RaportEwaluacjaUpowaznieniaView,
    RaportUczelniaEwaluacjaView,
    RaportZerowyEntry,
)
from raport_slotow.models.uczelnia import RaportSlotowUczelniaWiersz

from bpp.models import CHARAKTER_SLOTY
from bpp.models.cache import (
    Cache_Punktacja_Autora_Query,
    Cache_Punktacja_Autora_Query_View,
)


class RaportCommonMixin:
    def render_tytul_oryginalny(self, value):
        url = reverse("bpp:browse_rekord", args=(value.pk[0], value.pk[1]))
        return safe(f"<a href={url}>{value}</a>")

    def value_tytul_oryginalny(self, value):
        return value.tytul_oryginalny

    def render_zrodlo_informacje(self, value):
        if hasattr(value, "zrodlo_id") and value.zrodlo_id is not None:
            return f"{value.zrodlo} {value.szczegoly}"
        return f"{value.informacje} {value.szczegoly}"

    def render_autorzy_z_dyscypliny(self, value):
        if value:
            return ", ".join(value)

    def render_liczba_wszystkich_autorow(self, value):
        if value:
            return len(value)


class RaportSlotowAutorTable(RaportCommonMixin, tables.Table):
    class Meta:
        attrs = {"class": "small-table"}
        empty_text = "Brak danych"
        model = Cache_Punktacja_Autora_Query_View
        fields = (
            "tytul_oryginalny",
            "autorzy",
            "autorzy_z_dyscypliny",
            "liczba_autorow_z_dyscypliny",
            "liczba_wszystkich_autorow",
            "rok",
            "zrodlo_informacje",
            "dyscyplina",
            "punkty_kbn",
            "pkdaut",
            "slot",
        )

    tytul_oryginalny = Column("Tytuł oryginalny", "rekord")
    autorzy = Column(
        "Autorzy", "rekord.opis_bibliograficzny_zapisani_autorzy_cache", orderable=False
    )
    rok = Column("Rok", "rekord.rok", orderable=True)
    dyscyplina = Column(orderable=False)
    punkty_kbn = Column("Punkty PK", "rekord.punkty_kbn")
    zrodlo_informacje = Column(
        "Źródło / informacje", "rekord", empty_values=(), orderable=False
    )
    pkdaut = SummingColumn("Punkty dla autora", "pkdaut")
    slot = SummingColumn("Slot")
    autorzy_z_dyscypliny = Column(
        "Autorzy z dyscypliny",
        "zapisani_autorzy_z_dyscypliny",
        orderable=False,
    )
    liczba_autorow_z_dyscypliny = Column(
        "Liczba autorów z dyscypliny",
        "zapisani_autorzy_z_dyscypliny",
        orderable=False,
    )
    liczba_wszystkich_autorow = Column(
        "Liczba wszystkich autorów",
        "rekord.opis_bibliograficzny_autorzy_cache",
        orderable=False,
    )

    def render_liczba_autorow_z_dyscypliny(self, value):
        if value:
            return len(value)


class RaportSlotowUczelniaBezJednostekIWydzialowTable(tables.Table):
    class Meta:
        empty_text = "Brak danych"
        model = RaportSlotowUczelniaWiersz
        fields = (
            "autor",
            "pbn_id",
            "orcid",
            "dyscyplina",
            "pkd_aut_sum",
            "slot",
            "avg",
        )

    pkd_aut_sum = DecimalColumn("Suma punktów dla autora")
    slot = DecimalColumn("Slot")
    avg = Column("Średnio punktów dla autora na slot")
    dyscyplina = Column()
    pbn_id = Column("PBN ID", "autor.pbn_id")
    orcid = Column("ORCID", "autor.orcid")

    def __init__(self, od_roku, do_roku, slot, *args, **kw):
        self.od_roku = od_roku
        self.do_roku = do_roku
        self.slot = slot
        super().__init__(*args, **kw)

    def render_avg(self, value):
        return round(value, 4)

    def render_autor(self, value):
        url = (
            reverse("raport_slotow:index")
            + "?"
            + urllib.parse.urlencode(
                {
                    "obiekt": value.pk,
                    "od_roku": self.od_roku,
                    "do_roku": self.do_roku,
                    "dzialanie": const.DZIALANIE_SLOT,
                    "slot": self.slot,
                }
            )
        )
        return safe(f"<a href={url}>{value}</a>")

    def value_autor(self, value):
        return value


class RaportSlotowUczelniaTable(RaportSlotowUczelniaBezJednostekIWydzialowTable):
    class Meta:
        empty_text = "Brak danych"
        model = Cache_Punktacja_Autora_Query
        fields = (
            "autor",
            "pbn_id",
            "orcid",
            "jednostka",
            "wydzial",
            "dyscyplina",
            "pkd_aut_sum",
            "slot",
            "avg",
        )

    wydzial = Column("Wydział", accessor="jednostka.wydzial.nazwa")


class RaportSlotowZerowyTable(tables.Table):
    class Meta:
        empty_text = "Brak danych"
        model = RaportZerowyEntry
        fields = (
            "autor",
            "autor__aktualna_jednostka",
            "autor__pbn_id",
            "autor__orcid",
            "lata",
            "dyscyplina_naukowa",
        )


class RaportSlotowEwaluacjaTable(RaportCommonMixin, tables.Table):
    class Meta:
        attrs = {"class": "very-small-table"}
        empty_text = "Brak danych"
        model = RaportUczelniaEwaluacjaView
        fields = (
            "id",
            "tytul_oryginalny",
            "autorzy",
            "rok",
            "zrodlo_lub_wydawnictwo_nadrzedne",
            "informacje",
            "rodzaj_publikacji",
            "liczba_autorow_z_dyscypliny",
            "liczba_wszystkich_autorow",
            "punkty_pk",
            "autor",
            "aktualna_jednostka",
            "pbn_id",
            "orcid",
            "dyscyplina",
            "procent_dyscypliny",
            "subdyscyplina",
            "procent_subdyscypliny",
            "dyscyplina_rekordu",
            "upowaznienie_pbn",
            "profil_orcid",
            "pkdaut",
            "slot",
        )

    id = Column("ID publikacji", "rekord.id")
    tytul_oryginalny = Column("Tytuł oryginalny", "rekord")
    autorzy = Column(
        "Autorzy", "rekord.opis_bibliograficzny_zapisani_autorzy_cache", orderable=False
    )
    aktualna_jednostka = Column(
        "Aktualna jednostka", "autorzy.autor.aktualna_jednostka.nazwa"
    )
    rok = Column("Rok", "rekord.rok", orderable=True)
    zrodlo_informacje = None
    # Column(
    #    "Źródło / informacje", "rekord", empty_values=(), orderable=False
    # )
    zrodlo_lub_wydawnictwo_nadrzedne = Column(
        "Zródło lub wydawnictwo nadrzędne", "rekord", orderable=False
    )
    informacje = Column("Informacje", "rekord")

    upowaznienie_pbn = Column("Upoważnienie PBN", "autorzy")

    profil_orcid = Column("Profil ORCID", "autorzy")

    def render_upowaznienie_pbn(self, value):
        return value.upowaznienie_pbn

    def render_profil_orcid(self, value):
        return value.profil_orcid

    def render_zrodlo_lub_wydawnictwo_nadrzedne(self, value):
        if (
            hasattr(value, "wydawnictwo_nadrzedne_id")
            and value.wydawnictwo_nadrzedne_id is not None
        ):
            return value.wydawnictwo_nadrzedne.tytul_oryginalny
        if hasattr(value, "zrodlo_id") and value.zrodlo_id is not None:
            return value.zrodlo.nazwa
        return "123"

    def render_informacje(self, value):
        if (
            hasattr(value, "wydawnictwo_nadrzedne_id")
            and value.wydawnictwo_nadrzedne_id is not None
        ):
            return value.szczegoly
        return value.informacje

    rodzaj_publikacji = Column("Rodzaj", "rekord")
    liczba_autorow_z_dyscypliny = Column(
        "Liczba autorów z dyscypliny",
        "autorzy_z_dyscypliny",
        orderable=False,
    )
    liczba_wszystkich_autorow = Column(
        "Liczba wszystkich autorów",
        "rekord.opis_bibliograficzny_autorzy_cache",
        orderable=False,
    )
    punkty_pk = Column("PK", "rekord.punkty_kbn")
    autor = Column("Autor ewaluowany", "autorzy.autor")
    pbn_id = Column("PBN ID", "autorzy.autor.pbn_id")
    orcid = Column("ORCID", "autorzy.autor.orcid")
    dyscyplina = Column(
        "Dyscyplina 1", "autor_dyscyplina.dyscyplina_naukowa", orderable=False
    )
    procent_dyscypliny = Column(
        "% dyscypliny 1", "autor_dyscyplina.procent_dyscypliny", orderable=False
    )
    subdyscyplina = Column(
        "Dyscyplina 2", "autor_dyscyplina.subdyscyplina_naukowa", orderable=False
    )
    procent_subdyscypliny = Column(
        "% dyscypliny 2",
        "autor_dyscyplina.procent_subdyscypliny",
        orderable=False,
    )
    dyscyplina_rekordu = Column("dyscyplina rekordu", "autorzy.dyscyplina_naukowa")
    pkdaut = SummingColumn("Punkty dla autora", "pkdaut")
    slot = SummingColumn("Slot")

    def render_liczba_autorow_z_dyscypliny(self, value):
        if value:
            return len(value)

    def render_rodzaj_publikacji(self, value):
        if value.charakter_formalny.charakter_sloty:
            return CHARAKTER_SLOTY[value.charakter_formalny.charakter_sloty]
        if hasattr(value, "zrodlo_id") and value.zrodlo_id is not None:
            return "Artykuł"

    def render_autorzy(self, value):
        if value:
            if len(value) > 100:
                return value[:100] + "(...)"
            return value

    def value_autorzy(self, value):
        return value


class RaportEwaluacjaUpowaznieniaTable(RaportSlotowEwaluacjaTable):
    class Meta:
        attrs = {"class": "very-small-table"}
        model = RaportEwaluacjaUpowaznieniaView
        empty_text = "Brak danych"
        fields = (
            "id",
            "tytul_oryginalny",
            "autorzy",
            "rok",
            "zrodlo_lub_wydawnictwo_nadrzedne",
            "informacje",
            "rodzaj_publikacji",
            "liczba_wszystkich_autorow",
            "punkty_pk",
            "autor",
            "pbn_id",
            "orcid",
            "aktualna_jednostka",
            "dyscyplina",
            "procent_dyscypliny",
            "subdyscyplina",
            "procent_subdyscypliny",
            "dyscyplina_rekordu",
            "upowaznienie_pbn",
            "profil_orcid",
        )

    pkdaut = None
    slot = None

    aktualna_jednostka = Column(
        "Aktualna jednostka", "autorzy.autor.aktualna_jednostka"
    )



# Zaimportujmy wszystko
from bpp.models.abstract import *  # noqa
from bpp.models.autor import *  # noqa
from bpp.models.grant import *  # noqa
from bpp.models.patent import *  # noqa
from bpp.models.praca_doktorska import *  # noqa
from bpp.models.praca_habilitacyjna import *  # noqa
from bpp.models.profile import *  # noqa
from bpp.models.repozytorium import *  # noqa
from bpp.models.struktura import *  # noqa
from bpp.models.system import *  # noqa
from bpp.models.wydawnictwo_ciagle import *  # noqa
from bpp.models.wydawnictwo_zwarte import *  # noqa
from bpp.models.zrodlo import *  # noqa

# W tej tablicy znajdują się wszystkie modele dziedziczące z ModelPunktowany
MODELE_PUNKTOWANE = [
    Wydawnictwo_Zwarte,  # noqa
    Wydawnictwo_Ciagle,  # noqa
    Praca_Doktorska,  # noqa
    Praca_Habilitacyjna,  # noqa
    Patent,  # noqa
]  # noqa

# W tej tablicy znajdują się wszystkie modele będące powiązaniem rekordu
# z rekordem Autora
MODELE_AUTORSKIE = [
    Wydawnictwo_Zwarte_Autor,  # noqa
    Wydawnictwo_Ciagle_Autor,  # noqa
    Patent_Autor,  # noqa
]  # noqa

from .multiseek import BppMultiseekVisibility  # noqa

from bpp.models.cache import *  # noqa
from bpp.models.dyscyplina_naukowa import *  # noqa
from bpp.models.kierunek_studiow import Kierunek_Studiow  # noqa
from bpp.models.konferencja import *  # noqa
from bpp.models.openaccess import *  # noqa
from bpp.models.opi_2012 import *  # noqa
from bpp.models.seria_wydawnicza import *  # noqa
from bpp.models.sumy_views import *  # noqa

TABLE_TO_MODEL = {
    "bpp_wydawnictwo_ciagle": Wydawnictwo_Ciagle,  # noqa
    "bpp_wydawnictwo_zwarte": Wydawnictwo_Zwarte,  # noqa
    "bpp_praca_doktorska": Praca_Doktorska,  # noqa
    "bpp_praca_habilitacyjna": Praca_Habilitacyjna,  # noqa
    "bpp_patent": Patent,  # noqa
}  # noqa



# Generated by Django 3.0.14 on 2021-07-25 21:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0280_auto_20210725_2217"),
    ]

    operations = [
        migrations.AlterField(
            model_name="typ_odpowiedzialnosci",
            name="typ_ogolny",
            field=models.SmallIntegerField(
                choices=[
                    (0, "autor"),
                    (1, "redaktor"),
                    (2, "inny"),
                    (3, "tłumacz"),
                    (4, "komentator"),
                    (5, "recenzent"),
                    (6, "opracował"),
                    (7, "redaktor tłumaczenia"),
                ],
                db_index=True,
                default=0,
                help_text="Pole to jest używane celem rozróżniania typu odpowiedzialności\n        na cele eksportu do PBN (autor i redaktor) oraz może być też wykorzystywane\n        np. w raportach autorów i jednostek.\n        ",
                verbose_name="Ogólny typ odpowiedzialności",
            ),
        ),
    ]



import pytest
from django.core.exceptions import ValidationError

from ewaluacja2021 import const
from ewaluacja2021.tests.utils import curdir
from ewaluacja2021.validators import validate_xlsx, xlsx_header_validator


def test_validate_xlsx_bad():
    class FakeFile:
        name = __name__

    with pytest.raises(ValidationError):
        validate_xlsx(FakeFile)

    FakeFile.name = "unexistent"

    with pytest.raises(ValidationError):
        validate_xlsx(FakeFile)


def test_validate_xlsx_good():

    validate_xlsx(curdir("test_file.xlsx", __file__))


def test_xlsx_header_validator_bad():

    validator = xlsx_header_validator(const.IMPORT_MAKSYMALNYCH_SLOTOW_COLUMNS)

    with pytest.raises(ValidationError):
        validator(curdir("test_file_header_bad.xlsx", __file__))

    with pytest.raises(ValidationError):
        validator("unexsitent")


def test_xlsx_header_validator_good():

    validator = xlsx_header_validator(const.IMPORT_MAKSYMALNYCH_SLOTOW_COLUMNS)
    validator(curdir("test_file.xlsx", __file__))



# Generated by Django 3.0.14 on 2021-08-20 13:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0288_rekord_mat_isbn"),
    ]

    operations = [
        migrations.AddField(
            model_name="patent_autor",
            name="data_oswiadczenia",
            field=models.DateField(
                blank=True,
                help_text="Informacja eksportowana do PBN, gdy uzupełniono",
                null=True,
                verbose_name="Data oświadczenia",
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle_autor",
            name="data_oswiadczenia",
            field=models.DateField(
                blank=True,
                help_text="Informacja eksportowana do PBN, gdy uzupełniono",
                null=True,
                verbose_name="Data oświadczenia",
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte_autor",
            name="data_oswiadczenia",
            field=models.DateField(
                blank=True,
                help_text="Informacja eksportowana do PBN, gdy uzupełniono",
                null=True,
                verbose_name="Data oświadczenia",
            ),
        ),
    ]



# Generated by Django 1.11.8 on 2018-02-18 04:51

from collections import defaultdict

from django.db import migrations, models


def zmigruj_typy_odpowiedzialnosci(apps, schema_editor):
    # Typ odpowiedzialnosci dla PBN domyślnie ustawiony jest na
    # "autor", więc ustawiamy tutaj tylko takie rekordy, któe tego
    # autora nie mają...
    from bpp import const

    mapping = defaultdict(
        lambda: const.TO_INNY,
        {
            "aut": const.TO_AUTOR,
            "autkoresp": const.TO_AUTOR,
            "red": const.TO_REDAKTOR,
            "rednaukwydpol": const.TO_REDAKTOR,
            "komentarz": const.TO_KOMENTATOR,
            "kom": const.TO_KOMENTATOR,
            "recenzja": const.TO_RECENZENT,
            "rec": const.TO_RECENZENT,
            "opracował": const.TO_OPRACOWAL,
            "oprac": const.TO_OPRACOWAL,
            "tłzjęzang": const.TO_TLUMACZ,
            "tł": const.TO_TLUMACZ,
            "tłang": const.TO_TLUMACZ,
            "": const.TO_INNY,
        },
    )

    Typ_Odpowiedzialnosci = apps.get_model("bpp", "Typ_Odpowiedzialnosci")
    for elem in Typ_Odpowiedzialnosci.objects.all():
        v = (
            elem.skrot.lower()
            .replace(" ", "")
            .replace(".", "")
            .replace(":", "")
            .strip()
        )
        elem.typ_ogolny = mapping.get(v)
        elem.save()


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0115_auto_20171111_0038"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="typ_odpowiedzialnosci",
            options={
                "ordering": ["nazwa"],
                "verbose_name": "typ odpowiedzialności",
                "verbose_name_plural": "typy odpowiedzialności",
            },
        ),
        migrations.AddField(
            model_name="typ_odpowiedzialnosci",
            name="typ_ogolny",
            field=models.SmallIntegerField(
                choices=[
                    (0, "autor"),
                    (1, "redaktor"),
                    (2, "inny"),
                    (3, "tłumacz"),
                    (4, "komentator"),
                    (5, "recenzent"),
                    (6, "opracował"),
                ],
                default=0,
                help_text="Pole to jest używane celem rozróżniania typu odpowiedzialności\n        na cele eksportu do PBN (autor i redaktor) oraz może być też wykorzystywane\n        np. w raportach autorów i jednostek. \n        ",
                verbose_name="Typ odpowiedzialności dla PBN",
            ),
        ),
        migrations.RunPython(zmigruj_typy_odpowiedzialnosci, migrations.RunPython.noop),
    ]



# Generated by Django 3.0.11 on 2021-04-06 03:07

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("pbn_api", "0007_publication"),
        ("bpp", "0253_rekord_mat_slug"),
    ]

    operations = [
        migrations.AddField(
            model_name="uczelnia",
            name="pbn_uid",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="pbn_api.Institution",
            ),
        ),
    ]



import pytest

from crossref_bpp.views import pobierz_z_crossref
from pbn_api.tests.utils import middleware

from bpp.admin import Wydawnictwo_CiagleAdmin


@pytest.mark.vcr
@pytest.mark.django_db
def test_pobierz_z_crossref_nie_ma_rekordu(rf, admin_user, jezyki):
    req = rf.post("/", {"identyfikator_doi": "10.1080/1042819021000006394"})
    req.user = admin_user

    ret = pobierz_z_crossref(req, {}, Wydawnictwo_CiagleAdmin.crossref_templates)
    with middleware(req):
        assert "brak takiego DOI w bazie" in ret.rendered_content


@pytest.mark.vcr
@pytest.mark.django_db
def test_pobierz_z_crossref_form_errors(rf, admin_user):
    req = rf.post("/", {"identyfikator_doi": "aisjdfoasjdofaijsd"})
    req.user = admin_user

    ret = pobierz_z_crossref(req, {}, Wydawnictwo_CiagleAdmin.crossref_templates)
    with middleware(req):
        assert "nic po stronie CrossRef API" in ret.rendered_content



# Generated by Django 2.1.10 on 2019-10-21 18:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0184_autor_expertus_id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='autor',
            name='expertus_id',
            field=models.CharField(blank=True, db_index=True, max_length=10, null=True, unique=True, verbose_name='Identyfikator w bazie Expertus'),
        ),
    ]



# -*- coding: utf-8 -*-


from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('bpp', '0041_auto_20160802_2211'),
    ]

    operations = [
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='ostatnio_zmieniony_dla_pbn',
            field=models.DateTimeField(
                help_text=b'Moment ostatniej aktualizacji rekordu dla potrzeb PBN. To pole zmieni si\xc4\x99 automatycznie, gdy\n        nast\xc4\x85pi zmiana dowolnego z p\xc3\xb3l za wyj\xc4\x85tkiem blok\xc3\xb3w p\xc3\xb3l: \xe2\x80\x9epunktacja\xe2\x80\x9d, \xe2\x80\x9epunktacja komisji centralnej\xe2\x80\x9d,\n        \xe2\x80\x9eadnotacje\xe2\x80\x9d oraz pole \xe2\x80\x9estatus korekty\xe2\x80\x9d.',
                verbose_name=b'Ostatnio zmieniony (dla PBN)', auto_now_add=True),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='ostatnio_zmieniony_dla_pbn',
            field=models.DateTimeField(
                help_text=b'Moment ostatniej aktualizacji rekordu dla potrzeb PBN. To pole zmieni si\xc4\x99 automatycznie, gdy\n        nast\xc4\x85pi zmiana dowolnego z p\xc3\xb3l za wyj\xc4\x85tkiem blok\xc3\xb3w p\xc3\xb3l: \xe2\x80\x9epunktacja\xe2\x80\x9d, \xe2\x80\x9epunktacja komisji centralnej\xe2\x80\x9d,\n        \xe2\x80\x9eadnotacje\xe2\x80\x9d oraz pole \xe2\x80\x9estatus korekty\xe2\x80\x9d.',
                verbose_name=b'Ostatnio zmieniony (dla PBN)', auto_now_add=True),
        ),

    ]



# -*- encoding: utf-8 -*-
import argparse
import multiprocessing

from django.core.management import BaseCommand

from import_dbf.util import dbf2sql


class Command(BaseCommand):
    help = "Konwertuje plik DBF do zapytań SQLowych PostgreSQL"

    def add_arguments(self, parser):
        parser.add_argument("plik", nargs="+", type=argparse.FileType("rb"))
        parser.add_argument("--disable-multithreading", action="store_true")

    def handle(self, disable_multithreading, plik, *args, **options):
        if not disable_multithreading:
            p = multiprocessing.Pool(processes=multiprocessing.cpu_count())
            p.map(dbf2sql, [x.name for x in plik])
        else:
            for x in plik:
                dbf2sql(x.name)



from django.core.management import BaseCommand
from django.db import transaction

from ewaluacja2021.core.genetyczny import GAD


class Command(BaseCommand):
    def add_arguments(self, parser):
        parser.add_argument("--dyscyplina", default="nauki medyczne")
        parser.add_argument("--generations", default=1000, type=int)
        parser.add_argument("--saturate", default=300, type=int)
        parser.add_argument("--output-path", default=None, type=str)

    @transaction.atomic
    def handle(self, dyscyplina, generations, output_path, saturate, *args, **options):

        algorytm = GAD(
            nazwa_dyscypliny=dyscyplina,
            max_gen=generations,
            output_path=output_path,
            saturate=saturate,
        )
        algorytm.powitanie()
        algorytm.pracuj()
        algorytm.zrzuc_dane("genetyczny")
        algorytm.pozegnanie()



from django.db import models

from .base import BasePBNModel


class Country(BasePBNModel):
    code = models.CharField(max_length=5, primary_key=True)
    description = models.CharField(max_length=200)



import sys

import pytest
from django.utils import timezone

from long_running import const


def test_Report_various(report):
    report.create_report = lambda self: True

    report.mark_started()
    report.mark_finished_okay()
    try:
        raise NotImplementedError
    except BaseException:
        exc_type, exc_value, exc_traceback = sys.exc_info()
        report.mark_finished_with_error(exc_type, exc_value, exc_traceback)


def test_Report_task_create_report_good(report):
    report.create_report = lambda: True
    report.task_create_report()
    report.refresh_from_db()
    assert report.finished_successfully


def test_Report_task_create_report_bad(report):
    def bad_fun():
        raise ValueError("xxx")

    report.create_report = lambda: bad_fun()
    report.task_create_report(raise_exceptions=False)
    report.refresh_from_db()
    assert not report.finished_successfully
    assert "xxx" in report.traceback


def test_Operation_readable_exception(operation):
    assert operation.readable_exception() is None

    operation.traceback = "1\n2\n3"
    assert operation.readable_exception() == "3"


def test_Operation_mark_reset(operation):
    operation.mark_reset()
    assert True


def test_Operation_on_finished_with_error(operation):
    operation.on_finished_with_error()
    assert True


def test_Operation_perform(operation):
    with pytest.raises(NotImplementedError):
        operation.perform()


def test_Operation_get_redirect_prefix(operation):
    assert operation.get_redirect_prefix() == "test_bpp:testoperation"


def test_Operation_get_url(operation, mocker):
    rev = mocker.patch("long_running.models.reverse")
    operation.get_url("foo")
    rev.assert_called_once()


def test_Operation_get_state(operation):
    assert operation.get_state() == const.PROCESSING_NOT_STARTED
    operation.started_on = timezone.now()
    assert operation.get_state() == const.PROCESSING_STARTED
    operation.finished_on = timezone.now()
    operation.finished_successfully = False
    assert operation.get_state() == const.PROCESSING_FINISHED_WITH_ERROR
    operation.finished_successfully = True
    assert operation.get_state() == const.PROCESSING_FINISHED_SUCCESSFULLY

    operation.started_on = None
    assert operation.get_state() == const.PROCESSING_NOT_STARTED



# -*- coding: utf-8 -*-


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0064_autor_jednostka_aktualna'),
        ('bpp', '0051_auto_20161201_1137'),
    ]

    operations = [
    ]



# -*- encoding: utf-8 -*-
from pbn_api.integrator import synchronizuj_publikacje
from pbn_api.management.commands.util import PBNBaseCommand


class Command(PBNBaseCommand):
    def add_arguments(self, parser):
        super(Command, self).add_arguments(parser)
        parser.add_argument("--skip", default=0, type=int)

    def handle(self, app_id, app_token, base_url, user_token, skip, *args, **options):
        client = self.get_client(app_id, app_token, base_url, user_token)
        synchronizuj_publikacje(client, skip)



# -*- coding: utf-8 -*-


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0056_jednostka_trigger_jednostka_wydzial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='jednostka',
            name='wydzial',
            field=models.ForeignKey(on_delete=models.CASCADE, verbose_name=b'Wydzia\xc5\x82', blank=True, to='bpp.Wydzial', null=True),
        ),
    ]



# Generated by Django 3.0.14 on 2022-05-03 20:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0317_uczelnia_pokaz_tylko_nadrzedne"),
    ]

    operations = [
        migrations.AddConstraint(
            model_name="autor_jednostka",
            constraint=models.UniqueConstraint(
                condition=models.Q(podstawowe_miejsce_pracy=True),
                fields=("autor_id",),
                name="jedno_podstawowe_miejsce_pracy_na_autora",
            ),
        ),
    ]



# Generated by Django 3.0.14 on 2021-08-18 20:30

from django.db import migrations


def _create_idx(fld):
    #  create  index foo114 on pbn_api_publication using gin (upper("title") gin_trgm_ops);
    idx_name = f"pbn_api_pub_{fld}_idx"
    create = f'CREATE INDEX {idx_name} ON pbn_api_publication USING GIN (UPPER("{fld}") gin_trgm_ops);'
    delete = f"DROP INDEX {idx_name}"
    return create, delete


class Migration(migrations.Migration):

    dependencies = [
        ("pbn_api", "0027_przemapuj_rok_publikacji"),
    ]

    operations = [
        migrations.RunSQL(*_create_idx("mongoId")),
        migrations.RunSQL(*_create_idx("title")),
        migrations.RunSQL(*_create_idx("publicUri")),
        migrations.RunSQL(*_create_idx("doi")),
        migrations.RunSQL(*_create_idx("isbn")),
    ]
